/* Note: These are roughly in dependency order. */
:root,
.sidebyside {
  --rb-g-diff-box-header-bg: var(--if-light, #E9E9E9 linear-gradient(to bottom, #FFFFFF, var(--ink-p-grey-200) 70%, var(--ink-p-grey-200))) var(--if-dark, var(--ink-p-cool-grey-300));
  --rb-g-diff-box-header-fg: var(--ink-p-container-fg);
  --rb-g-diff-box-header-border: var(--ink-u-border-thin) var(--if-light, var(--ink-p-container-border-color)) var(--if-dark, transparent) solid;
  --rb-g-diff-header-bg: var(--if-light, #DAEBFF) var(--if-dark, var(--ink-p-cool-grey-400));
  --rb-g-diff-header-fg: var(--ink-p-fg);
  --rb-g-diff-header-border: var(--ink-u-border-thin) var(--if-light, #a7cfff) var(--if-dark, transparent) solid;
  --rb-g-diff-chunk-border: 1px rgba(0, 0, 0, 0.12) solid;
  --rb-g-diff-highlight-text-bg: var(--if-light, #ffdd61) var(--if-dark, goldenrod);
  --rb-g-diff-highlight-text-fg: black;
}
.sidebyside {
  /*
   * Most of the moved range border sits on the line number cell as a
   * border-right, and part sits on the content cell as a border-left. This
   * gives us a full 4px, which is nicely visible, while allowing us to keep
   * a reasonable padding in both types of cells, without also needing to
   * press any text right up against the border.
   */
  background: transparent;
  border-collapse: separate;
  border-spacing: 0;
  color: var(--ink-p-fg-on-light);
  padding: 0;
  width: 100%;
  overflow: hidden;
  margin-bottom: -1px;
  /*
   * On mobile, we'll be making a few major changes to layout:
   *
   * 1. Rather than table layout, this will use grid layout, allowing us to
   *    have control over where lines begin.
   *
   *    We use subgrid if available to make column sizes consistent across the
   *    diff, but fall back to reasonably-minimum-enforced sizes on browsers
   *    lacking subgrid support.
   *
   * 2. There are three columns: The original file line number, the modified
   *    file line number, and the content. Only one side is represented per
   *    row.
   *
   * 3. The <tbody> and <thead> tags will be styled with borders, rather than
   *    the <td> and <th> tags. When using table layout, styling must go on
   *    the cells, rather than the tbody/thead, but this is not the case with
   *    grid.
   *
   * 4. The "replace" chunks now display as pairs of deletes and inserts,
   *    helping users see what changes are made.
   */
}
.sidebyside.diff-error td {
  background: var(--ink-p-accent-warning-bg);
  color: var(--ink-p-accent-warning-fg);
  padding: 1em;
}
.sidebyside.diff-error td a:not(.btn) {
  color: var(--ink-p-link-fg-on-light);
  font-weight: bold;
}
.sidebyside.diff-error td h2 {
  font-size: 10pt;
  margin: 0em 0 2em 0;
  padding: 0;
}
.sidebyside.diff-error td h2 .rb-icon {
  vertical-align: text-bottom;
}
.sidebyside.diff-error .error-details {
  display: none;
}
.sidebyside.diff-error .error-details pre {
  background: white;
  border: 1px #999 solid;
  padding: 1em;
}
.sidebyside.diff-error .error-details td {
  padding-top: 0;
}
.sidebyside.diff-error .revision-row th {
  padding-left: 4em;
}
.sidebyside.newfile col.left {
  width: 0%;
}
.sidebyside.newfile col.right {
  width: 100%;
}
.sidebyside.diff-binary {
  /*
     * When an image is larger than the diff container, this prevents the
     * controls in the header from being clipped and allows the container to
     * have a horizontal scrollbar if needed.
     */
  table-layout: fixed;
}
.sidebyside.deleted,
.sidebyside.newfile {
  /*
     * NOTE: This only applies to expanded regions in diff fragments in
     *       reviews.
     */
}
.sidebyside.deleted .rb-c-diff-collapse-button,
.sidebyside.newfile .rb-c-diff-collapse-button {
  /*
       * This will position it dead-center. The `right: 50%` will align the
       * right edge with the middle, and then we shift over by half the
       * button width.
       */
  right: 50%;
  transform: translateX(50%);
}
.sidebyside.selecting-col-1:not(.newfile) td.r,
.sidebyside.selecting-col-1:not(.newfile) td.r * {
  -webkit-touch-callout: none;
  -webkit-user-select: none;
  user-select: none;
  /* These must be defined as two rules, or Firefox will drop them both. */
}
.sidebyside.selecting-col-1:not(.newfile) td.r::selection,
.sidebyside.selecting-col-1:not(.newfile) td.r *::selection {
  background: transparent;
}
.sidebyside.selecting-col-1:not(.newfile) td.r::-moz-selection,
.sidebyside.selecting-col-1:not(.newfile) td.r *::-moz-selection {
  background: transparent;
}
.sidebyside.selecting-col-3 td.l,
.sidebyside.selecting-col-3 td.l * {
  -webkit-touch-callout: none;
  -webkit-user-select: none;
  user-select: none;
  /* These must be defined as two rules, or Firefox will drop them both. */
}
.sidebyside.selecting-col-3 td.l::selection,
.sidebyside.selecting-col-3 td.l *::selection {
  background: transparent;
}
.sidebyside.selecting-col-3 td.l::-moz-selection,
.sidebyside.selecting-col-3 td.l *::-moz-selection {
  background: transparent;
}
.sidebyside.-hide-ducs .rb-o-duc::before {
  display: none;
}
.sidebyside.-hide-ducs .rb-o-duc::after {
  content: attr(data-char);
}
.sidebyside a {
  color: inherit;
  text-decoration: none;
}
.sidebyside col.left {
  width: 50%;
}
.sidebyside col.right {
  width: 50%;
}
.sidebyside col.line {
  width: 1%;
  /* Make sure this doesn't stretch if the header stretches. */
}
.sidebyside img.header-file-icon {
  vertical-align: middle;
}
.sidebyside pre {
  font-size: inherit;
  line-height: 140%;
  margin: 0;
  padding-left: 2px;
  /*
     * We ideally want break-spaces, which behaves like pre-wrap but will break
     * in the middle of whitespace. Not all browsers support this, so we have
     * to fall back.
     */
  white-space: pre-wrap;
  white-space: break-spaces;
  /*
     * overflow-wrap is the modern name, but some browsers need word-break
     * to work right. Edge, IE, and Safari, for instance, do not support this or
     * treat it correctly at the time of this writing (April 11, 2017). Guides
     * suggest specifying both, so we're specifying both.
     */
  overflow-wrap: break-word;
  word-break: break-all;
}
.sidebyside pre .tb {
  /*
       * Firefox (at least up through 131.02) overflows rather than breaking
       * when we have tabs and `word-break: break-all;`. We could use
       * `break-word` above, but that'd affect normal text. Fortunately we can
       * just do that here and work around Firefox's bug.
       */
  word-break: break-word;
}
.sidebyside .fa-warning {
  color: var(--ink-p-red-700);
}
.sidebyside .indent {
  color: var(--rb-theme-diff-indent-fg);
}
.sidebyside .unindent {
  color: var(--rb-theme-diff-unindent-fg);
}
.sidebyside .moved-row-start pre {
  margin-top: 4px;
}
.sidebyside .moved-row td.moved-from pre,
.sidebyside .moved-row td.moved-to pre {
  padding-right: 3px;
}
.sidebyside .moved-row td.moved-from {
  border-left: 1px var(--rb-theme-diff-move-from-flag-bg) solid;
}
.sidebyside .moved-row td.moved-to {
  border-left: 1px var(--rb-theme-diff-move-to-flag-bg) solid;
}
.sidebyside .moved-row th.moved-from,
.sidebyside .moved-row th.moved-to {
  padding-right: 1px;
}
.sidebyside .moved-row th.moved-from {
  border-right: 3px var(--rb-theme-diff-move-from-flag-bg) solid;
}
.sidebyside .moved-row th.moved-to {
  border-right: 3px var(--rb-theme-diff-move-to-flag-bg) solid;
}
.sidebyside .moved-to .moved-flag {
  background: var(--rb-theme-diff-move-to-flag-bg);
  color: var(--rb-theme-diff-move-to-flag-fg);
}
.sidebyside .moved-from .moved-flag {
  background: var(--rb-theme-diff-move-from-flag-bg);
  color: var(--rb-theme-diff-move-from-flag-fg);
}
.sidebyside .moved-flag {
  display: inline-block;
  font-size: 7pt;
  padding: 0;
  text-decoration: none;
  /*
     * We need to compensate for some spacing in the cells. The TD for the
     * cell is @diff-cell-padding around the sides, which is simple.
     *
     * We need to offset a bit more on the left to compensate for the border.
     * Parent cells have different border colors and widths above and to the
     * side, which creates a diagonal. This means there's what appears to be
     * a gap between the moved range line and the flag. We cover that up by
     * moving the flag over the left a bit.
     */
  margin: -1px -1px 1px -4px;
}
.sidebyside .moved-to-start,
.sidebyside .moved-from-start {
  padding-top: 0;
}
.sidebyside .moved-to-start .moved-flag,
.sidebyside .moved-from-start .moved-flag {
  border-radius: 0 var(--ink-u-border-radius-std) var(--ink-u-border-radius-std) 0;
  padding: 3px 1em 3px 0.5em;
}
.sidebyside > tbody {
  --_rb-diff-bg: var(--rb-theme-diff-equals-bg);
  --_rb-diff-fg: var(--rb-theme-diff-equals-fg);
  --_rb-diff-linenum-bg: var(--rb-theme-diff-equals-linenum-bg);
  --_rb-diff-linenum-fg: var(--rb-theme-diff-equals-linenum-fg);
  --_rb-diff-highlight-bg: var(--rb-theme-diff-equals-highlight-bg);
  background: var(--_rb-diff-bg);
  color: var(--_rb-diff-fg);
}
.sidebyside > tbody > tr {
  /*
       * The first line in a range shown in a diff comment fragment on a
       * review.
       */
}
.sidebyside > tbody > tr.selected > td,
.sidebyside > tbody > tr.selected > th {
  background: var(--_rb-diff-highlight-bg);
}
.sidebyside > tbody > tr.first td,
.sidebyside > tbody > tr.first th {
  border-top: 1px var(--if-light, rgba(0, 0, 0, 0.12)) var(--if-dark, transparent) solid;
}
.sidebyside > tbody > tr.highlight-anchor td,
.sidebyside > tbody > tr.highlight-anchor th {
  background: var(--if-dark, var(--ink-p-blue-200)) var(--if-light, #F3CBFF);
}
.sidebyside > tbody > tr > td {
  background: inherit;
  color: inherit;
  padding: 1px;
  vertical-align: top;
}
.sidebyside > tbody > tr > td a {
  color: var(--ink-p-link-fg);
  text-decoration: underline;
}
.sidebyside > tbody > tr > td .collapse-floater {
  position: relative;
}
.sidebyside > tbody > tr > td .rb-c-diff-collapse-button {
  /*
           * This positions it fairly center over the middle line numbers.
           * We'd normally shift over 50% of the element width, but the 70%
           * nicely covers the left and middle * line numbers.
           */
  position: absolute;
  right: 0;
  transform: translateX(70%);
}
.sidebyside > tbody > tr > th {
  font-weight: normal;
  background: var(--_rb-diff-linenum-bg);
  color: var(--_rb-diff-linenum-fg);
  cursor: pointer;
  padding-left: 1em;
  padding-right: 4px;
  text-align: right;
  vertical-align: top;
  white-space: nowrap;
  /*
         * The minimum width is calculated so that the th is always as wide as
         * the expand by 20 lines button, which is 28px wide.
         */
  min-width: calc(28px - 1em - 4px);
  -webkit-touch-callout: none;
  -webkit-user-select: none;
  user-select: none;
  /* These must be defined as two rules, or Firefox will drop them both. */
}
.sidebyside > tbody > tr > th::selection {
  background: transparent;
}
.sidebyside > tbody > tr > th::-moz-selection {
  background: transparent;
}
.sidebyside > tbody > tr > th .fa-warning {
  margin-left: 0.5em;
}
.sidebyside > tbody.binary .inline-actions-header {
  background: #e1e1e1;
  border-bottom: 1px #B1AFAF solid;
}
.sidebyside > tbody.binary .inline-actions-header td {
  padding: 0;
}
.sidebyside > tbody.binary .inline-actions-header td:first-child {
  border-right: 1px #D0D0D0 solid;
}
.sidebyside > tbody.binary .inline-actions-right li,
.sidebyside > tbody.binary .inline-actions-left li {
  border-radius: 0;
}
.sidebyside > tbody.binary .inline-actions-right li:hover,
.sidebyside > tbody.binary .inline-actions-left li:hover {
  background-color: #d5d5d5;
}
.sidebyside > tbody.binary .inline-actions-right {
  float: right;
}
.sidebyside > tbody.binary .inline-actions-right a {
  border-left: 1px #B1AFAF solid;
}
.sidebyside > tbody.binary .inline-actions-left {
  float: left;
}
.sidebyside > tbody.binary .inline-actions-left a {
  border-right: 1px #B1AFAF solid;
  border-left: 0px;
}
.sidebyside > tbody.binary .inline-files-container td.diff-review-ui {
  padding: 0;
}
.sidebyside > tbody.binary .file-thumbnail-container {
  margin: 0;
  overflow: hidden;
  padding: 1em;
  text-align: center;
  white-space: nowrap;
}
.sidebyside > tbody.binary p {
  margin: 0;
  padding: 4px;
}
.sidebyside > tbody.binary td {
  padding: 1em;
}
.sidebyside > tbody.delete {
  --_rb-diff-bg: var(--rb-theme-diff-delete-bg);
  --_rb-diff-fg: var(--rb-theme-diff-delete-fg);
  --_rb-diff-linenum-bg: var(--rb-theme-diff-delete-linenum-bg);
  --_rb-diff-linenum-fg: var(--rb-theme-diff-delete-linenum-fg);
  --_rb-diff-highlight-bg: var(--rb-theme-diff-delete-highlight-bg);
}
.sidebyside > tbody.equal {
  /*
       * Don't include a border for adjacent equals chunks. This will happen
       * when expanding diffs, and is specific to equals.
       */
}
.sidebyside > tbody.equal + tbody.equal tr.first td,
.sidebyside > tbody.equal + tbody.equal tr.first th {
  border-top: 0;
}
.sidebyside > tbody.insert {
  --_rb-diff-bg: var(--rb-theme-diff-insert-bg);
  --_rb-diff-fg: var(--rb-theme-diff-insert-fg);
  --_rb-diff-linenum-bg: var(--rb-theme-diff-insert-linenum-bg);
  --_rb-diff-linenum-fg: var(--rb-theme-diff-insert-linenum-fg);
  --_rb-diff-highlight-bg: var(--rb-theme-diff-insert-highlight-bg);
}
.sidebyside > tbody.replace {
  --_rb-diff-bg: var(--rb-theme-diff-replace-bg);
  --_rb-diff-fg: var(--rb-theme-diff-replace-fg);
  --_rb-diff-linenum-bg: var(--rb-theme-diff-replace-linenum-bg);
  --_rb-diff-linenum-fg: var(--rb-theme-diff-replace-linenum-fg);
  --_rb-diff-highlight-bg: var(--rb-theme-diff-replace-highlight-bg);
}
.sidebyside > tbody.replace.dimmed {
  background: #FFFFFF;
}
.sidebyside > tbody.replace.dimmed .hl {
  background: #FFFFFF;
}
.sidebyside > tbody.replace.dimmed th {
  background: #F0F0F0;
}
.sidebyside > tbody.replace .hl {
  background: var(--rb-g-diff-highlight-text-bg);
  color: var(--rb-g-diff-highlight-text-fg);
}
.sidebyside > tbody.diff-header {
  background: var(--rb-g-diff-header-bg);
  color: var(--rb-g-diff-header-fg);
}
.sidebyside > tbody.diff-header + tbody td,
.sidebyside > tbody.diff-header + tbody th {
  border-top: 0;
}
.sidebyside > tbody.diff-header a {
  text-decoration: none;
  color: inherit;
}
.sidebyside > tbody.diff-header code {
  margin: 0 2px;
  font-size: inherit;
  word-break: break-all;
  word-wrap: break-word;
  vertical-align: middle;
}
.sidebyside > tbody.diff-header img {
  vertical-align: middle;
  padding: 1px;
}
.sidebyside > tbody.diff-header td,
.sidebyside > tbody.diff-header th {
  background: inherit;
  text-align: center;
  padding: 0.5em;
}
.sidebyside > tbody.diff-header tr:first-child td,
.sidebyside > tbody.diff-header tr:first-child th {
  border-top: var(--rb-g-diff-header-border);
}
.sidebyside > tbody.diff-header tr:last-child td,
.sidebyside > tbody.diff-header tr:last-child th {
  border-bottom: var(--rb-g-diff-header-border);
}
.sidebyside thead {
  background: var(--rb-g-diff-box-header-bg);
  color: var(--rb-g-diff-box-header-fg);
  /*
     * Remove the top border on the diff header or chunk following the file
     * header, so that the file header's border takes precedence.
     */
}
.sidebyside thead + tbody tr.first td,
.sidebyside thead + tbody tr:first-child td,
.sidebyside thead + tbody tr.first th,
.sidebyside thead + tbody tr:first-child th {
  /*
           * Ideally we wouldn't use !important, but we otherwise need to
           * have this rule for each type of tbody, which we don't want.
           */
  border-top: 0 !important;
}
.sidebyside thead th {
  font-size: 120%;
  font-weight: bold;
  text-align: left;
  text-overflow: ellipsis;
}
.sidebyside thead .filename-row th {
  overflow: hidden;
  padding: 8px;
}
.sidebyside thead .revision-row th {
  border-bottom: var(--rb-g-diff-box-header-border);
  font-size: 100%;
  font-weight: normal;
  padding: 8px 0;
}
.sidebyside thead .revision-row th.revision-col {
  overflow: hidden;
}
.sidebyside thead .revision-row th .rb-icon {
  vertical-align: text-top;
}
.sidebyside thead th.controls,
.sidebyside th.controls {
  font-size: 100%;
  font-weight: normal;
  padding: 2px 0 2px 2px;
  vertical-align: top;
}
@media screen and (max-width: 720px), screen and (max-device-width: 720px) and (orientation: landscape) {
  .sidebyside:not(.newfile, .deleted) {
    display: grid;
    grid-template-columns: 5em 5em 1fr;
    /* With table layout removed, this becomes a standard element. Hide it. */
    /*
       * The diff file header will continue to show two columns, one for the
       * original file and one for the modified file.
       *
       * If we only show one filename, the original filename will take the full
       * width. Its revision will also take as much of the column space as
       * possible, leaving "New Change" to take a minimum amount.
       *
       * If we show both, they'll each get as much of the column space as is
       * necessary (likely 50%).
       */
    /*
       * If CSS subgrid is supported by the browser, apply this to select parts
       * of the diff. This will help ensure columns line up correctly. Note that
       * children may inherit this via `grid-template-columns: inherit` above.
       *
       * If not available, then default minimum widths will be used to try to
       * keep columns aligned.
       */
  }
  .sidebyside:not(.newfile, .deleted) colgroup {
    display: none;
  }
  .sidebyside:not(.newfile, .deleted) thead {
    display: grid;
    grid-column: 1 / 4;
    grid-template-columns: auto auto;
    /* Override any JavaScript-set widths. */
  }
  .sidebyside:not(.newfile, .deleted) thead th {
    min-width: revert !important;
    max-width: revert !important;
  }
  .sidebyside:not(.newfile, .deleted) thead .filename-row {
    display: grid;
    grid-column: 1 / 3;
    grid-template-columns: inherit;
    /*
           * Style the original filename column to take the full width by
           * default.
           */
    /* Style the modified filename to take half, if present. */
  }
  .sidebyside:not(.newfile, .deleted) thead .filename-row > :nth-child(1) {
    grid-column: 1 / 3;
  }
  .sidebyside:not(.newfile, .deleted) thead .filename-row > :nth-child(1):has(+ th) {
    /* If we have a modified filename, make it only take half. */
    grid-column: 1 / 2;
  }
  .sidebyside:not(.newfile, .deleted) thead .filename-row > :nth-child(2) {
    grid-column: 2 / 3;
  }
  .sidebyside:not(.newfile, .deleted) thead .revision-row {
    display: grid;
    grid-column: 1 / 3;
    grid-template-columns: inherit;
    /* Hide the empty spacing cells before each revision. */
    /* Style the original and modified revisions to take half the space. */
  }
  .sidebyside:not(.newfile, .deleted) thead .revision-row > :nth-child(1),
  .sidebyside:not(.newfile, .deleted) thead .revision-row > :nth-child(3) {
    display: none;
  }
  .sidebyside:not(.newfile, .deleted) thead .revision-row > :nth-child(2) {
    grid-column: 1 / 2;
  }
  .sidebyside:not(.newfile, .deleted) thead .revision-row > :nth-child(4) {
    grid-column: 2 / 3;
  }
  .sidebyside:not(.newfile, .deleted) thead .revision-row th {
    padding: 8px;
  }
  .sidebyside:not(.newfile, .deleted) tbody {
    display: grid;
    grid-column: 1 / 4;
    grid-template-columns: inherit;
    /* Hide the very first and last <tbody> borders in the diff. */
    /*
         * The following changes are made to the diff collapse header:
         *
         * 1. The button for expanding the original side will be placed in the
         *    first column of the first row.
         *
         * 2. The button for expanding the modified side will be placed in the
         *    second column of the first row.
         *
         * 3. Only one side's function/class header is shown. If the modified
         *    file's header is present, then that is shown. Otherwise, the
         *    original file's header is shown. This keeps it clean and
         *    prioritizes looking at the modified file. We don't allow expanding
         *    to the original file header if both are present anyway.
         *
         *    This takes all remaining columns.
         */
    /*
         * The following changes are made to the deleted chunks <tbody>:
         *
         * 1. The empty modified content area is hidden.
         *
         * 2. The original file line number is shown in the first line number
         *    column. The empty modified line number is shown in the second
         *    line number column.
         *
         * 3. Border management logic is applied to the <tbody>, mirroring the
         *    logic normally applied for the desktop version of the diff viewer
         *    to <td> and <tr>.
         */
    /*
         * The following changes are made to the equal chunks <tbody>:
         *
         * 1. The empty original content area is hidden.
         *
         * 2. The empty original file line number is shown in the first line
         *    number column. The modified line number is shown in the second
         *    line number column.
         *
         * 3. Border management logic is applied to the <tbody>, mirroring the
         *    logic normally applied for the desktop version of the diff viewer
         *    to <td> and <tr>.
         */
    /*
         * The following changes are made to the inserted chunks <tbody>:
         *
         * 1. The empty original content area is hidden.
         *
         * 2. The empty original file line number is shown in the first line
         *    number column. The modified line number is shown in the second
         *    line number column.
         *
         * 3. Border management logic is applied to the <tbody>, mirroring the
         *    logic normally applied for the desktop version of the diff viewer
         *    to <td> and <tr>.
         */
    /*
         * The following changes are made to the replaced chunks <tbody>:
         *
         * 1. Replaced lines are shown as pairs of deletes and inserts. Their
         *    styles merge with any adjacent deletes or inserts, respectively.
         *
         * 2. The original file line number is shown in the first line number
         *    column. The modified line number is shown in the second line
         *    number column.
         *
         * 3. Border management logic is applied to the <tbody>, mirroring the
         *    logic normally applied for the desktop version of the diff viewer
         *    to <td> and <tr>.
         */
    /*
         * Ensure each row inherits layout from its parent, and takes up the
         * full available width.
         *
         * We also need to clear borders on cells so we can manage them on
         * <tbody>.
         */
  }
  .sidebyside:not(.newfile, .deleted) tbody:first-of-type {
    border-top: 0 !important;
  }
  .sidebyside:not(.newfile, .deleted) tbody:last-child {
    border-bottom: 0 !important;
  }
  .sidebyside:not(.newfile, .deleted) tbody.diff-header {
    border-top: 1px var(--if-light, var(--ink-p-container-border-color)) var(--if-dark, transparent) solid;
    border-bottom: 1px var(--if-light, var(--ink-p-container-border-color)) var(--if-dark, transparent) solid;
  }
  .sidebyside:not(.newfile, .deleted) tbody.diff-header > tr {
    /*
             * The row containing the "Expand above" and "Expand all lines"
             * buttons.
             */
    /* The row containing the "Expand below" and header buttons. */
  }
  .sidebyside:not(.newfile, .deleted) tbody.diff-header > tr:first-child td,
  .sidebyside:not(.newfile, .deleted) tbody.diff-header > tr:last-child td,
  .sidebyside:not(.newfile, .deleted) tbody.diff-header > tr:first-child th,
  .sidebyside:not(.newfile, .deleted) tbody.diff-header > tr:last-child th {
    border: 0;
  }
  .sidebyside:not(.newfile, .deleted) tbody.diff-header > tr:nth-child(1) {
    /* The "Expand above" button. */
    /* The "Expand all lines" button. */
  }
  .sidebyside:not(.newfile, .deleted) tbody.diff-header > tr:nth-child(1) > :nth-child(1) {
    grid-column: 1 / 2;
  }
  .sidebyside:not(.newfile, .deleted) tbody.diff-header > tr:nth-child(1) > :nth-child(2) {
    grid-column: 2 / 4;
  }
  .sidebyside:not(.newfile, .deleted) tbody.diff-header > tr:nth-child(2) {
    /* The "Expand below" button. */
    /*
               * The original header.
               *
               * This will be the header for the original file if it differs
               * from the modified file, in which case it's hidden.
               */
    /* The modified header will take the remaining space. */
  }
  .sidebyside:not(.newfile, .deleted) tbody.diff-header > tr:nth-child(2) > :nth-child(1) {
    align-self: end;
    grid-column: 1 / 2;
  }
  .sidebyside:not(.newfile, .deleted) tbody.diff-header > tr:nth-child(2) > :nth-child(2) {
    grid-column: 2 / 4;
  }
  .sidebyside:not(.newfile, .deleted) tbody.diff-header > tr:nth-child(2) > :nth-child(2):has(+ td) {
    display: none;
  }
  .sidebyside:not(.newfile, .deleted) tbody.diff-header > tr:nth-child(2) > :nth-child(3) {
    grid-column: 2 / 4;
  }
  .sidebyside:not(.newfile, .deleted) tbody.rb-c-diff-file-notice {
    /* Make sure this doesn't disturb the layout. Fit it best we can. */
    grid-template-columns: auto;
  }
  .sidebyside:not(.newfile, .deleted) tbody.delete,
  .sidebyside:not(.newfile, .deleted) tbody.insert,
  .sidebyside:not(.newfile, .deleted) tbody.replace {
    border-top: var(--rb-g-diff-chunk-border);
    border-bottom: var(--rb-g-diff-chunk-border);
  }
  .sidebyside:not(.newfile, .deleted) tbody.delete {
    background: var(--rb-theme-diff-delete-bg);
    /*
           * If there's a replace chunk right below, hide the border to make it
           * appear as one set of deletes.
           */
  }
  .sidebyside:not(.newfile, .deleted) tbody.delete:has(+ tbody.replace) {
    border-bottom: 0;
  }
  .sidebyside:not(.newfile, .deleted) tbody.delete > tr {
    /* Place the original line number in the first column. */
    /* Place the deleted line content in the third column. */
    /* Place the empty modified line number in the second column. */
    /* Hide the modified line content. */
  }
  .sidebyside:not(.newfile, .deleted) tbody.delete > tr.moved-row > :nth-child(1) {
    padding-right: calc(50% + 4px - 3px);
  }
  .sidebyside:not(.newfile, .deleted) tbody.delete > tr > :nth-child(1) {
    grid-column: 1 / 3;
    padding-right: calc(50% + 4px);
  }
  .sidebyside:not(.newfile, .deleted) tbody.delete > tr > :nth-child(2) {
    grid-column: 3 / 4;
  }
  .sidebyside:not(.newfile, .deleted) tbody.delete > tr > :nth-child(3) {
    display: none;
  }
  .sidebyside:not(.newfile, .deleted) tbody.delete > tr > :nth-child(4) {
    display: none;
  }
  .sidebyside:not(.newfile, .deleted) tbody.equal {
    /* Don't show any borders between equals chunks. */
  }
  .sidebyside:not(.newfile, .deleted) tbody.equal + tbody.equal {
    border-top: 0;
  }
  .sidebyside:not(.newfile, .deleted) tbody.equal > tr {
    /* Place the empty original line number in the first column. */
    /* Hide the original line content. */
    /* Place the modified line number in the second column. */
    /* Place the modified line content in the third column. */
  }
  .sidebyside:not(.newfile, .deleted) tbody.equal > tr > :nth-child(1) {
    grid-column: 1 / 2;
  }
  .sidebyside:not(.newfile, .deleted) tbody.equal > tr > :nth-child(4) {
    display: none;
  }
  .sidebyside:not(.newfile, .deleted) tbody.equal > tr > :nth-child(3) {
    grid-column: 2 / 3;
    grid-row: 1 / 2;
  }
  .sidebyside:not(.newfile, .deleted) tbody.equal > tr > :nth-child(2) {
    grid-column: 3 / 4;
    grid-row: 1 / 2;
  }
  .sidebyside:not(.newfile, .deleted) tbody.insert {
    /*
           * Prioritize the insert chunk's border over an equal, and hide it
           * outright if there's a replace below (which will show as an insert).
           */
  }
  .sidebyside:not(.newfile, .deleted) tbody.insert + tbody.equal tr.first,
  .sidebyside:not(.newfile, .deleted) tbody.insert + tbody.replace tr.first {
    border-top: 0;
  }
  .sidebyside:not(.newfile, .deleted) tbody.insert > tr {
    /* Place the empty original line number in the first column. */
    /* Hide the deleted line content. */
    /* Place the modified line number in the second column. */
    /* Place the modified line content in the third column. */
  }
  .sidebyside:not(.newfile, .deleted) tbody.insert > tr > :nth-child(1) {
    grid-column: 1 / 2;
  }
  .sidebyside:not(.newfile, .deleted) tbody.insert > tr > :nth-child(2) {
    display: none;
  }
  .sidebyside:not(.newfile, .deleted) tbody.insert > tr > :nth-child(3) {
    grid-column: 2 / 3;
  }
  .sidebyside:not(.newfile, .deleted) tbody.insert > tr > :nth-child(4) {
    grid-column: 3 / 4;
  }
  .sidebyside:not(.newfile, .deleted) tbody.replace {
    /*
           * If there's an insert chunk right below, hide the border to make it
           * appear as one set of deletes.
           */
    /*
           * Prioritize the delete chunk's border over any other, as it provides
           * a stronger contrast. This is the same as with ``.delete``.
           */
  }
  .sidebyside:not(.newfile, .deleted) tbody.replace:has(+ tbody.insert) {
    border-bottom: 0;
  }
  .sidebyside:not(.newfile, .deleted) tbody.replace + tbody.equal,
  .sidebyside:not(.newfile, .deleted) tbody.replace + tbody.delete,
  .sidebyside:not(.newfile, .deleted) tbody.replace + tbody.insert,
  .sidebyside:not(.newfile, .deleted) tbody.replace + tbody.replace {
    border-top: 0;
  }
  .sidebyside:not(.newfile, .deleted) tbody.replace > tr {
    /*
             * The original file line number spans the first two columns on the
             * first row, offset as best as possible by half the column area,
             * and styled as a delete.
             */
    /*
             * The original file content is placed in the third column on the
             * first row and is styled as a delete.
             */
    /*
             * The modified file line number spans the first two columns on the
             * second row, aligned with the other inserted line numbers, and is
             * styled as an insert.
             */
    /*
             * The modified file content is placed in the third column on the
             * second row and is styled as a delete.
             */
  }
  .sidebyside:not(.newfile, .deleted) tbody.replace > tr > :nth-child(1) {
    background: var(--rb-theme-diff-delete-linenum-bg);
    grid-column: 1 / 3;
    padding-right: calc(50% + 4px);
  }
  .sidebyside:not(.newfile, .deleted) tbody.replace > tr > :nth-child(2) {
    background: var(--rb-theme-diff-delete-bg);
    grid-column: 3 / 4;
  }
  .sidebyside:not(.newfile, .deleted) tbody.replace > tr > :nth-child(3) {
    background: var(--rb-theme-diff-insert-linenum-bg);
    grid-column: 1 / 3;
  }
  .sidebyside:not(.newfile, .deleted) tbody.replace > tr > :nth-child(4) {
    background: var(--rb-theme-diff-insert-bg);
    grid-column: 3 / 4;
  }
  .sidebyside:not(.newfile, .deleted) tbody > tr {
    display: grid;
    grid-column: 1 / 4;
    grid-template-columns: inherit;
  }
  .sidebyside:not(.newfile, .deleted) tbody > tr.first td,
  .sidebyside:not(.newfile, .deleted) tbody > tr.first th {
    border-top: 0;
  }
  .sidebyside:not(.newfile, .deleted) tbody > tr td .rb-c-diff-collapse-button {
    right: 50%;
    transform: none;
  }
  .sidebyside:not(.newfile, .deleted) tbody > tr th {
    /* Clip the left side of the text if it goes out of bounds. */
    direction: rtl;
    overflow: hidden;
    text-overflow: clip;
  }
  @supports (grid-template-columns: subgrid) {
    .sidebyside:not(.newfile, .deleted) {
      grid-template-columns: max-content max-content 1fr;
    }
    .sidebyside:not(.newfile, .deleted) tbody,
    .sidebyside:not(.newfile, .deleted) thead .filename-row,
    .sidebyside:not(.newfile, .deleted) thead .revision-row {
      grid-template-columns: subgrid;
    }
  }
}
.commentflag {
  border-radius: 1.6em;
  display: none;
  left: -0.7em;
  margin-top: -0.3em;
  position: absolute;
  width: 1.6em;
}
.commentflag .commentflag-shadow {
  border-radius: 1.6em;
  opacity: 0.1;
  background-color: black;
  border: 1px solid black;
  bottom: 0;
  left: 0.2em;
  position: absolute;
  right: 0;
  top: 0.2em;
  width: 100%;
}
.commentflag .commentflag-inner {
  border-radius: 1.6em;
  background-color: var(--rb-p-flag-published-bg);
  border: 1px solid var(--rb-p-flag-published-border-color);
  bottom: 0.2em;
  color: var(--rb-p-flag-published-fg);
  cursor: pointer;
  font-size: 90%;
  font-weight: normal;
  left: 0;
  line-height: 1.7em;
  position: absolute;
  right: 0.2em;
  text-align: center;
  top: 0;
  vertical-align: top;
  width: 100%;
  z-index: 20;
}
.commentflag .commentflag-inner span {
  background: transparent !important;
  -webkit-touch-callout: none;
  -webkit-user-select: none;
  user-select: none;
  /* These must be defined as two rules, or Firefox will drop them both. */
}
.commentflag .commentflag-inner span::selection {
  background: transparent;
}
.commentflag .commentflag-inner span::-moz-selection {
  background: transparent;
}
.selected .commentflag .commentflag-inner {
  background-color: var(--rb-p-flag-published-bg);
}
.selected .commentflag .commentflag-inner,
.commentflag .commentflag-inner:hover {
  background-color: var(--rb-p-flag-published-hover-bg);
}
.commentflag.draft .commentflag-inner {
  background-color: var(--rb-p-flag-draft-bg);
  border-color: var(--rb-p-flag-draft-border-color);
}
.selected .commentflag.draft .commentflag-inner,
.commentflag.draft .commentflag-inner:hover {
  background-color: var(--rb-p-flag-draft-hover-bg);
}
.ghost-commentflag {
  cursor: pointer;
  position: absolute;
  left: 0.1em;
  margin-top: -0.1em;
  height: 21px;
}
.ghost-commentflag .commentflag-inner {
  background-color: #eeeeec;
  border-color: #888a85;
}
#diffs {
  list-style: none;
  margin: 0;
  padding: 0;
  /* Allows highlight chunks to be absolute relative to this. */
  position: relative;
}
#diffs div.index ol {
  margin-bottom: 20px;
  padding-left: 30px;
}
#diffs .diff-container {
  margin-bottom: 3em;
  position: relative;
}
#diffs .diff-container:last-child {
  margin-bottom: 0;
}
#diffs .diff-box {
  border: var(--ink-g-border-container);
  border-radius: 6px;
  box-shadow: var(--ink-g-shadow-std);
  overflow: hidden;
}
#diffs .diff-highlight {
  background-color: rgba(16, 179, 255, 0.54);
  display: block;
  font-size: 0;
  /* Prevents the 13px minimum height in IE6 */
  position: absolute;
  left: 0;
  top: 0;
}
/**
 * The diff file index table.
 *
 * This can appear either within the review request box, or as a docked item
 * within the unified review banner.
 */
table.rb-c-diff-file-index {
  border-collapse: collapse;
  border: var(--ink-c-data-table-border);
  padding: 0;
  width: 100%;
}
table.rb-c-diff-file-index tr:first-child td {
  border-top: 0;
}
table.rb-c-diff-file-index td {
  background: var(--ink-c-data-table-body-bg);
  padding: 0.6em;
  margin: 0;
  border-top: var(--ink-c-data-table-row-border);
  vertical-align: top;
}
table.rb-c-diff-file-index td.diff-chunks-cell {
  color: var(--ink-p-fg-weak);
  text-align: right;
  width: 70%;
}
table.rb-c-diff-file-index td.diff-file-icon {
  padding: 2px 0 0 2px;
  vertical-align: middle;
}
table.rb-c-diff-file-index td.diff-file-icon .rb-icon {
  width: 20px;
  height: 20px;
}
table.rb-c-diff-file-index td.diff-file-icon .djblets-o-spinner {
  font-size: 14px;
  margin: 3px;
}
table.rb-c-diff-file-index td.diff-file-info {
  padding-left: 0.3em;
  white-space: nowrap;
  vertical-align: middle;
  width: 30%;
}
table.rb-c-diff-file-index td.diff-file-info .diff-file-rename {
  color: var(--ink-p-fg-weak);
  display: block;
  font-size: 90%;
  font-style: italic;
  padding: 1em 0 0 0;
}
table.rb-c-diff-file-index td a {
  color: var(--ink-p-link-fg);
  text-decoration: none;
}
table.rb-c-diff-file-index td a:hover {
  text-decoration: underline;
}
table.rb-c-diff-file-index td a.dimmed {
  color: #ABABAB;
}
table.rb-c-diff-file-index td .diff-chunks {
  max-height: 2.5em;
  overflow: hidden;
  text-align: right;
}
table.rb-c-diff-file-index td .diff-chunks a {
  border-radius: 50%;
  display: inline-block;
  margin: 3px 2px 0 2px;
  width: 8px;
  height: 8px;
}
table.rb-c-diff-file-index td .diff-chunks a.insert {
  background-color: var(--rb-p-diff-insert-graph-color);
}
table.rb-c-diff-file-index td .diff-chunks a.delete {
  background-color: var(--rb-p-diff-delete-graph-color);
}
table.rb-c-diff-file-index td .diff-chunks a.replace {
  background-color: var(--rb-p-diff-replace-graph-color);
}
/**
 * The diff file index when docked into the unified banner.
 *
 * Structure:
 *     <div class="rb-c-diff-file-index-dock">
 *      <div class="rb-c-diff-file-index-dock__table">
 *       <table class="rb-c-diff-file-index">...</table>
 *       <a href="#" class="rb-c-diff-file-index-dock__disclosure">
 *        <span class="fa fa-bars"></span>
 *       </a>
 *      </div>
 *     </div>
 */
.rb-c-diff-file-index-dock {
  display: flex;
  padding: var(--ink-u-spacing-m);
  /**
   * The disclosure icon for when the table is collapsed.
   */
}
.rb-c-diff-file-index-dock__disclosure {
  font-size: 120%;
  padding: 4px 0 4px 8px;
}
.rb-c-diff-file-index-dock__table {
  border: var(--ink-c-data-table-border);
  flex-grow: 1;
  overflow: hidden;
}
.rb-c-diff-file-index-dock table.rb-c-diff-file-index,
.rb-c-diff-file-index-dock tr,
.rb-c-diff-file-index-dock td {
  border: none;
}
.rb-c-diff-file-index-dock.-is-expanded .rb-c-diff-file-index-dock__table {
  transition: max-height 0.3s;
}
.rb-c-diff-file-index-dock.-is-expanded table {
  transform: inherit !important;
  transition: transform 0.3s;
}
/****************************************************************************
 * Diff information
 ****************************************************************************/
#diff-details {
  border-spacing: 8px;
  /*
   * XXX This should be replaced by rb-c-review-request-fieldset usage, or
   *     similar.
   */
}
#diff-details.loading .commit-list-container,
#diff-details.loading .diff-index-container {
  background-color: #FFFFFF;
  border: 1px #C0C0C0 solid;
  font-size: 16px;
  height: 16px;
  padding: 1em;
}
#diff-details #diff_revision_label h1 {
  margin: 0;
  padding: 0;
}
#diff-details .main {
  padding: 1em;
}
#diff-details .main h1,
#diff-details .main p {
  margin: 1em 0;
  padding: 0;
}
#diff-details #diff_revision_label h1,
#diff-details .section-header-label {
  color: var(--rb-p-review-request-field-label-color);
  font-size: 12px;
  font-weight: bold;
}
#diff-details .section-header-label {
  margin: 1em 0;
  padding: 1em 0 0 0;
}
.revision-selector-grabbed,
.revision-selector-grabbed * {
  cursor: grabbing !important;
}
.revision-selector {
  margin: 3em 1.5em 1.5em 1.5em;
  position: relative;
}
.revision-selector .revision-selector-trough {
  border-bottom: 1px solid black;
}
.revision-selector .revision-selector-tick {
  position: absolute;
  top: -8px;
  height: 16px;
  border-left: 1px solid black;
}
.revision-selector .revision-selector-label {
  position: absolute;
  top: -26px;
  user-select: none;
  -moz-user-select: none;
  -ms-user-select: none;
  -webkit-user-select: none;
}
.revision-selector .revision-selector-label.revision-selector-label-active {
  cursor: pointer;
}
.revision-selector .revision-selector-handle {
  position: absolute;
  top: -9px;
  z-index: 2;
  cursor: grab;
}
.revision-selector .revision-selector-range {
  position: absolute;
  background-color: #6a7d99;
  top: -1px;
  height: 4px;
  z-index: 1;
}
/****************************************************************************
 * Comments hint
 ****************************************************************************/
#diff_comments_hint .-is-current {
  font-weight: bold;
}
/****************************************************************************
 * Pagination
 ****************************************************************************/
.paginate-link,
.paginate-current {
  padding: 2px 4px;
  border: 1px solid #DDDDDD;
}
.paginate-current {
  background: #417690;
  color: #f4f379;
  font-weight: bold;
}
#pagination2 {
  margin-top: 1em;
}
/**
 * Displayed Unicode Character.
 *
 * This is used to show information on a possibly otherwise-invisible or
 * misleading Unicode character.
 *
 * Structure:
 *     <span class="rb-o-duc" data-codepoint="..." data-char="..."
 *           title="..."></span>
 */
.rb-o-duc::before {
  background: var(--if-dark, var(--ink-p-red-100)) var(--if-light, white);
  border-radius: 2px;
  color: var(--if-dark, white) var(--if-light, red);
  font-weight: normal;
  font-style: normal;
  padding: 0 0.5ch;
  /* Use outline instead of border to avoid affecting layout. */
  outline: 1px var(--ink-p-red-300) solid;
  content: "U+" attr(data-codepoint);
}
/* TODO: Reuse the colors from diffviewer.less, once they're moved out. */
.image-review-ui-diff-thumbnail .orig-image {
  border: 1px #FF7777 solid;
  display: inline-block;
}
.image-review-ui-diff-thumbnail .modified-image {
  border: 1px #63C363 solid;
  display: inline-block;
  margin-left: 5px;
}
.image-review-ui {
  background: var(--rb-c-review-request-bg);
  border-radius: 0 0 6px 6px;
  position: relative;
}
.image-review-ui .image-content {
  background: var(--if-dark, black) var(--if-light, white);
  overflow-x: auto;
  position: relative;
  /* Center the image within the box. */
  display: flex;
  justify-content: center;
  align-items: center;
  /*
     * We set a minimum height primarily so that we have room for the
     * zoom level menu, both in the file attachment review UI and in the
     * diff viewer. 15em is a good number for the resolutions we offer today.
     */
  min-height: 15em;
}
.image-review-ui .review-ui-header table {
  width: 100%;
}
.image-review-ui .review-ui-error {
  text-align: center;
  padding: 2em;
}
.review-ui-inline .image-review-ui {
  padding: 0;
}
.image-review-ui .image-single-revision {
  display: grid;
  align-items: center;
  grid-template-columns: 1fr auto 1fr;
}
.image-review-ui .image-single-revision .caption {
  grid-column: 2;
}
.image-review-ui img {
  display: block;
  margin: 0 auto;
  padding: 0;
}
.image-review-ui .caption {
  text-align: center;
}
.image-review-ui .image-diffs {
  padding: 2em;
  text-align: center;
}
.image-review-ui .image-diffs .image-slider {
  margin: 2em auto 0 auto;
  width: 200px;
}
.image-review-ui .image-diffs .orig-image {
  border: 1px #FF7777 solid;
}
.image-review-ui .image-diffs .modified-image {
  border: 1px #63C363 solid;
}
.image-review-ui .image-diffs .image-container {
  display: inline-block;
  float: none;
  margin: 2em;
}
.image-review-ui .image-diffs .image-diff-difference canvas {
  border: 1px #CCCCCC solid;
}
.image-review-ui .image-diffs .image-diff-two-up {
  display: flex;
  flex-wrap: wrap;
  justify-content: center;
}
.image-review-ui .image-diffs .image-diff-onion .image-containers,
.image-review-ui .image-diffs .image-diff-split .image-containers {
  margin: auto;
  position: relative;
}
.image-review-ui .image-diffs .image-diff-onion .image-containers .orig-image,
.image-review-ui .image-diffs .image-diff-split .image-containers .orig-image,
.image-review-ui .image-diffs .image-diff-onion .image-containers .modified-image,
.image-review-ui .image-diffs .image-diff-split .image-containers .modified-image {
  display: block;
  margin: 0;
  position: absolute;
}
.image-review-ui .image-diff-split-container-orig,
.image-review-ui .image-diff-split-container-modified {
  overflow: hidden;
  position: absolute;
}
.image-review-ui .image-diff-split-container-orig .orig-image {
  left: 0;
}
.image-review-ui .image-diff-split-container-modified {
  border-left: 1px solid #999999;
  right: 0;
}
.image-review-ui .image-diff-split-container-modified .modified-image {
  right: 0;
}
.image-review-ui .image-diff-modes {
  align-items: center;
  display: grid;
}
.image-review-ui .image-diff-modes.-has-modes {
  grid-template-columns: 1fr repeat(4, min-content) 1fr;
}
.image-review-ui .image-diff-modes.-has-modes > li:first-child {
  grid-column: 2;
}
.image-review-ui .selection {
  border: 1px var(--rb-p-flag-published-bg) solid;
  position: absolute;
}
.image-review-ui .selection.draft {
  border: 1px var(--rb-p-flag-draft-bg) solid;
}
.image-review-ui .selection.draft .selection-flag {
  background-color: var(--rb-p-flag-draft-bg);
  color: var(--rb-p-flag-draft-fg);
}
.image-review-ui .selection.draft.can-update-bound .selection-flag {
  cursor: move;
}
.image-review-ui .selection.draft.can-update-bound .resize-icon {
  background-color: var(--rb-p-flag-draft-bg);
  bottom: 0;
  right: 0;
  position: absolute;
  height: 0.5em;
  width: 0.5em;
  cursor: se-resize;
}
.image-review-ui .selection-flag {
  background-color: var(--rb-p-flag-published-bg);
  color: var(--rb-p-flag-published-fg);
  cursor: pointer;
  height: 2em;
  left: 0px;
  line-height: 170%;
  text-align: center;
  top: 0px;
  width: 2em;
}
.image-review-ui .selection-container {
  cursor: crosshair;
  position: absolute;
  margin: 0;
  z-index: 30;
}
.image-review-ui .selection-rect {
  border: 1px #ff0000 dashed;
  position: absolute;
}
.image-review-ui .image-resolution-menu,
.image-review-ui .image-resolution-menu-wrapper {
  justify-self: end;
}
.image-review-ui .image-resolution-menu .ink-c-menu-label {
  /**
     * Populate a menu label schema.
     *
     * This will provide the structure for a menu label component, populating
     * the parts of the component with the provided style rules.
     *
     * Menu labels contain text, an optional icon, and an optional drop-down
     * icon.
     *
     * Version Added:
     *     0.5
     *
     * Args:
     *     @name (string):
     *         The name of the CSS class that this schema would populate.
     *
     *     @schema-rules (ruleset, optional):
     *         Any rules to apply to part of the schema.
     *
     *     @specialize-schema-rules (ruleset, optional):
     *         Any additional specialized rules to apply to part of the schema.
     *
     *         This is a convenience to allow themes or specializations of
     *         components to easily inject additional rules into the schema.
     */
  /**
     * Add rules to a component based on the current context's schema.
     *
     * This is used within an existing ``.populate()`` mixin to add new
     * rules for one or more parts. It takes care of generating the selector
     * for the component as well.
     *
     * Within the context, this will be available as ``.add()``.
     *
     * Version Added:
     *     0.5
     *
     * Args:
     *     @rules (rulset):
     *         The rules to add to the component.
     *
     * Example:
     *     .add({
     *         @state-hover: {
     *             background: blue;
     *             color: red;
     *         };
     *     });
     */
  /**
     * Add schema and specialized rules for the given rules key.
     *
     * This is used inside a schema definition to add the caller's rules for
     * a given rules key. It will add the rules found in ``@schema-rules``
     * in the current context, followed by the rules in ``@specialize-rules``.
     *
     * This cannot be called outside of a schema definition.
     *
     * Within the context, this will be available as ``.add-rules()``.
     *
     * Version Added:
     *     0.5
     *
     * Args:
     *     @rules-key (string):
     *         The key within the rules definitions to add.
     *
     * Example:
     *     .add-rules('state-hover');
     */
  /**
       * Main part of the menu label component.
       *
       * DOM Attributes:
       *     aria-controls (string):
       *         This must be set to the ID of the contained menu that this
       *         label manages.
       *
       *     aria-expanded (boolean, optional):
       *         This must be set to ``true`` when the menu is open.
       *
       *     aria-haspopup (boolean):
       *         This must be set to ``true``.
       *
       *     role (string):
       *         This must be set to ``menuitem``.
       *
       * Modifiers:
       *     -opens-up:
       *         The menu will appear above the label.
       *
       * Structure:
       *     <a class="@{name}
       *               [-opens-up]"
       *        aria-controls="..."
       *        aria-haspopup="true"
       *        role="menuitem"
       *        [aria-disabled="true"]
       *        [aria-expanded="true"]>
       *      <span class="@{name}__inner" ...>
       *       ...
       *      </span>
       *      <menu class="@{name}__menu ..." ...>
       *       ...
       *      </menu>
       *     </a>
       */
  /**
       * The drop-down icon.
       *
       * This is an optional dropdown icon shown alongside the label.
       *
       * Structure:
       *     <span class="@{name}__dropdown-icon ..."</span>
       */
  /**
       * The icon shown alongside the text.
       *
       * Structure:
       *     <span class="@{name}__icon ..."></span>
       */
  /**
       * The inner element containing presentational information.
       *
       * Structure:
       *     <span class="@{name}__inner">
       *      [<span class="@{name}__icon ..." ...></span>]
       *      <span class="@{name}__text ..." ...></span>
       *      [<span class="@{name}__dropdown-icon ..." ...></span>]
       *     </span>
       */
  /**
       * The menu controlled by the label.
       *
       * See the Menu component for the full list of attributes and
       * customization options.
       *
       * Structure:
       *     <menu class="@{name}__menu @{menu:name} ..." ...>
       *      ...
       *     </menu>
       */
  /**
       * The text shown for the label.
       *
       * Structure:
       *     <span class="@{name}__text"></span>
       */
}
.image-review-ui .image-resolution-menu .ink-c-menu-label,
.image-review-ui .image-resolution-menu .ink-c-menu-label:link,
.image-review-ui .image-resolution-menu .ink-c-menu-label:visited {
  /*
       * Note that we need to cover both the "@name" and "name" key forms.
       * This is the reason for the apparent duplication below.
       */
}
.image-review-ui .image-resolution-menu .ink-c-menu-label:hover {
  /*
       * Note that we need to cover both the "@name" and "name" key forms.
       * This is the reason for the apparent duplication below.
       */
}
.image-review-ui .image-resolution-menu .ink-c-menu-label[aria-disabled="true"] {
  /*
       * Note that we need to cover both the "@name" and "name" key forms.
       * This is the reason for the apparent duplication below.
       */
}
.image-review-ui .image-resolution-menu .ink-c-menu-label[aria-expanded="true"] {
  /*
       * Note that we need to cover both the "@name" and "name" key forms.
       * This is the reason for the apparent duplication below.
       */
}
.image-review-ui .image-resolution-menu .ink-c-menu-label[aria-expanded="true"].-opens-up {
  /*
       * Note that we need to cover both the "@name" and "name" key forms.
       * This is the reason for the apparent duplication below.
       */
}
.image-review-ui .image-resolution-menu .ink-c-menu-label[aria-expanded="true"]:not(.-opens-up) {
  /*
       * Note that we need to cover both the "@name" and "name" key forms.
       * This is the reason for the apparent duplication below.
       */
}
.image-review-ui .image-resolution-menu .ink-c-menu-label__dropdown-icon {
  /*
       * Note that we need to cover both the "@name" and "name" key forms.
       * This is the reason for the apparent duplication below.
       */
}
.image-review-ui .image-resolution-menu .ink-c-menu-label__icon {
  /*
       * Note that we need to cover both the "@name" and "name" key forms.
       * This is the reason for the apparent duplication below.
       */
}
.image-review-ui .image-resolution-menu .ink-c-menu-label__inner {
  /*
       * Note that we need to cover both the "@name" and "name" key forms.
       * This is the reason for the apparent duplication below.
       */
}
.image-review-ui .image-resolution-menu .ink-c-menu-label__menu {
  /*
       * Note that we need to cover both the "@name" and "name" key forms.
       * This is the reason for the apparent duplication below.
       */
  /* Overlap the right border of the review UI. */
  margin-right: -1px;
  /* Anchor the menu to the right. */
  right: 0;
}
.image-review-ui .image-resolution-menu .ink-c-menu-label__text {
  /*
       * Note that we need to cover both the "@name" and "name" key forms.
       * This is the reason for the apparent duplication below.
       */
}
/****************************************************************************
 * General text-based review styles
 ****************************************************************************/
.review-ui-box .text-review-ui {
  border-radius: 6px;
}
.review-ui-box .text-review-ui .review-ui-header {
  /*
     * We set this instead of turning off the border to keep the gradient from
     * stopping too soon on Chrome and Firefox.
     */
  border-bottom-color: transparent;
  min-height: 0;
}
.review-ui-box .text-review-ui .review-ui-header .text-review-ui-views .rb-c-tabs {
  padding: 1em 0 0 5em;
}
.review-ui-box .text-review-ui .text-review-ui-text-table,
.review-ui-box .text-review-ui .text-review-ui-rendered-table {
  border-radius: 0 0 5px 5px;
}
.review-ui-box .text-review-ui .text-review-ui-text-table .revision-row th,
.review-ui-box .text-review-ui .text-review-ui-rendered-table .revision-row th {
  font-weight: bold;
}
.review-ui-box .text-review-ui .text-review-ui-text-table tbody:last-child tr:last-child td:last-child,
.review-ui-box .text-review-ui .text-review-ui-rendered-table tbody:last-child tr:last-child td:last-child {
  border-radius: 0 0 5px 0;
}
.review-ui-box .text-review-ui .text-review-ui-text-table tbody:last-child tr:last-child th:first-child,
.review-ui-box .text-review-ui .text-review-ui-rendered-table tbody:last-child tr:last-child th:first-child {
  border-radius: 0 0 0 5px;
}
.review-ui-box .text-review-ui .text-review-ui-text-table tbody td h1,
.review-ui-box .text-review-ui .text-review-ui-rendered-table tbody td h1,
.review-ui-box .text-review-ui .text-review-ui-text-table tbody td h2,
.review-ui-box .text-review-ui .text-review-ui-rendered-table tbody td h2,
.review-ui-box .text-review-ui .text-review-ui-text-table tbody td h3,
.review-ui-box .text-review-ui .text-review-ui-rendered-table tbody td h3,
.review-ui-box .text-review-ui .text-review-ui-text-table tbody td h4,
.review-ui-box .text-review-ui .text-review-ui-rendered-table tbody td h4,
.review-ui-box .text-review-ui .text-review-ui-text-table tbody td h5,
.review-ui-box .text-review-ui .text-review-ui-rendered-table tbody td h5,
.review-ui-box .text-review-ui .text-review-ui-text-table tbody td h6,
.review-ui-box .text-review-ui .text-review-ui-rendered-table tbody td h6,
.review-ui-box .text-review-ui .text-review-ui-text-table tbody td p,
.review-ui-box .text-review-ui .text-review-ui-rendered-table tbody td p {
  margin-top: 0;
  margin-bottom: 0;
}
.review-ui-box .text-review-ui .review-ui-error {
  text-align: center;
  padding: 2em;
}
.review-ui-box .text-review-ui .sidebyside {
  border-top: var(--rb-g-diff-box-header-border);
  margin: 0;
}
.text-review-ui-comment-thumbnail {
  background: inherit;
}
#attachment_revision_selector,
#revision_label {
  padding-top: 4px;
  padding-left: 12px;
}
/****************************************************************************
 * Markdown-specific styles
 ****************************************************************************/
.markdown-review-ui td {
  padding-left: 2px;
}
.markdown-review-ui td tbody * {
  margin: 0;
  padding: 0;
}
.markdown-review-ui td a {
  color: blue;
  text-decoration: underline;
}
.markdown-review-ui td h1 {
  font-size: 2em;
}
.markdown-review-ui td ul,
.markdown-review-ui td ol {
  padding-left: 2em;
}
:root {
  --rb-c-status-updates-failure-text-color: var(--ink-p-accent-error-fg-on-container);
  --rb-c-status-updates-not-yet-run-text-color: var(--ink-p-cyan-700);
  --rb-c-status-updates-pending-text-color: var(--ink-p-brown-700);
  --rb-c-status-updates-success-text-color: var(--ink-p-accent-success-fg-on-container);
}
/****************************************************************************
 * Review-specific macros
 ****************************************************************************/
/****************************************************************************
 * Code Mirror
 ****************************************************************************/
.CodeMirror {
  border: var(--ink-g-border-input);
  height: auto;
  margin: var(--rb-c-textarea-margin);
  cursor: text;
  /**
   * Highlight Markdown string literals and wrap it in a box.
   *
   * This is a bit complex, due to how CodeMirror represents literals. For
   * a text like::
   *
   *     `literal`
   *
   * The following spans are generated::
   *
   *     <span class="cm-formatting cm-formatting-code cm-rb-markdown-code"/>
   *     <span class="cm-rb-markdown-code"/>
   *     <span class="cm-formatting cm-formatting-code cm-rb-markdown-code"/>
   *
   * (The ``.cm-formatting-code`` spans represent the backticks.)
   *
   * Furthermore, when selected, we may get several of that inner span.
   *
   * The goal is to display a curved rectangle around the whole string of
   * spans, and to do so with the border sitting just outside the content
   * box.
   *
   * To do this, we place the border and offsets in ``:before``. This avoids
   * affecting the bounding box of the line (previous versions of Review Board
   * used negative margins, which had side-effects).
   *
   * We also have to figure out the starting and ending ``.cm-formatting-code``
   * backtick spans in a range, without hitting issues when there are
   * side-by-side literal blocks. To do this, we:
   *
   * 1) Set some defaults (offsets and top/bottom borders) that pertain to
   *    every one of the spans.
   *
   * 2) Set a default border-left on the ``.cm-formatting-code`` spans,
   *    aimed at the first span in a series.
   *
   * 3) Use a more complex ``:not() + ...`` rule to attempt to match the
   *    last ``.cm-formatting-code`` span, where we set a border-right and
   *    unset the border-left.
   *
   *    We use the ``:not()`` in order to skip any text that may have
   *    followed a previous set of spans. Without this, we'd match the
   *    first border and would unset the border-left if it followed another
   *    literal.
   */
}
.CodeMirror .CodeMirror-lines {
  padding: var(--rb-c-textarea-spacing);
}
.CodeMirror .CodeMirror-scroll {
  /*
     * Prevent Chrome (and maybe other browsers) from scrolling the page
     * when trying to scroll past the bounds of the text editor.
     */
  overscroll-behavior-y: none;
}
.CodeMirror pre {
  padding: 0;
}
.CodeMirror pre.CodeMirror-line,
.CodeMirror pre.CodeMirror-line-like {
  /* Turn off CodeMirror's own padding, since we're setting ours. */
  padding: 0;
}
.CodeMirror .cm-rb-markdown-code {
  background: var(--ink-p-code-literal-bg);
  color: var(--ink-p-code-literal-fg);
  display: inline-block;
  position: relative;
}
.CodeMirror .cm-rb-markdown-code:before {
  content: "";
  border-top: 1px var(--ink-p-code-literal-border-color) solid;
  border-bottom: 1px var(--ink-p-code-literal-border-color) solid;
  position: absolute;
  left: -1px;
  right: -1px;
  top: -1px;
  bottom: -1px;
}
.CodeMirror .cm-rb-markdown-code.cm-formatting-code:before {
  border-left: 1px var(--ink-p-code-literal-border-color) solid;
  border-top-left-radius: 3px;
  border-bottom-left-radius: 3px;
}
.CodeMirror .cm-rb-markdown-code:not(.cm-formatting-code) + .cm-rb-markdown-code.cm-formatting-code:before {
  border-left: 0;
  border-right: 1px var(--ink-p-code-literal-border-color) solid;
  border-top-left-radius: 0;
  border-top-right-radius: 3px;
  border-bottom-right-radius: 3px;
  border-bottom-left-radius: 0;
}
.CodeMirror .cm-rb-markdown-code.CodeMirror-selectedtext {
  background: inherit;
}
.CodeMirror .cm-rb-markdown-code.cm-formatting-code-block {
  background: none;
}
.CodeMirror .cm-rb-markdown-code.cm-formatting-code-block:before {
  border: 0;
  border-radius: 0;
}
.markdown-info {
  color: var(--ink-p-link-fg);
  font-size: 8pt;
  font-weight: normal;
  float: right;
  line-height: 25px;
  margin-right: 0.5em;
  text-decoration: none;
}
.markdown-info:hover {
  text-decoration: underline;
}
/****************************************************************************
 * Review UIs
 ****************************************************************************/
.review-ui-box.has-review-ui-box-content .review-request-actions-container .actions > li:last-child {
  border-radius: 0 5px 0 0;
}
.review-ui-box.has-prev-attachment .rb-c-review-request {
  margin-left: 1.5em;
}
.review-ui-box.has-next-attachment .rb-c-review-request {
  margin-right: 1.5em;
}
.review-ui-box .actions-container .actions > li:last-child {
  border-radius: 0 5px 5px 0;
}
.review-ui-box .review-ui-box-content {
  border: var(--rb-c-review-request-border);
  border-top: 0;
  clear: both;
  padding: 0;
  min-height: 5em;
}
.review-ui-header {
  border-bottom: var(--rb-c-review-request-border);
  background: var(--rb-c-review-request-bg);
  min-height: 2em;
}
.review-ui-header h1 {
  margin: 0;
  padding: var(--ink-u-spacing-s);
  font-size: 10pt;
}
.review-ui-header h1.file-attachment-single-revision {
  text-align: center;
}
.dummy-review-ui .review-ui-header table {
  width: 100%;
}
.dummy-review-ui .review-ui-header table .caption {
  text-align: center;
}
.dummy-review-ui-error {
  padding: 2em;
  text-align: center;
}
.review-ui-next-attachment,
.review-ui-prev-attachment {
  background: var(--rb-c-review-request-bg);
  border: var(--rb-c-review-request-border);
  color: var(--ink-p-fg);
  cursor: pointer;
  box-shadow: 0 0 4px rgba(0, 0, 0, 0.3);
  padding: 2px;
  position: fixed;
  top: 50%;
  transition: transform 0.3s, background 0.3s, margin 0.3s;
  z-index: var(--ink-z-menu);
}
.review-ui-next-attachment:hover,
.review-ui-prev-attachment:hover {
  transform: translateY(-50%);
}
.review-ui-next-attachment a,
.review-ui-prev-attachment a {
  color: inherit;
  text-decoration: none;
}
.review-ui-next-attachment .file-container,
.review-ui-prev-attachment .file-container {
  display: inline-block;
  float: none;
  padding: var(--ink-u-spacing-s) 0;
  vertical-align: middle;
}
.review-ui-next-attachment .file-container .file,
.review-ui-prev-attachment .file-container .file {
  margin: 0;
}
.review-ui-file-attachment-nav-button-overlay {
  position: absolute;
  left: 0;
  top: 0;
  right: 0;
  bottom: 0;
  z-index: 30;
}
.review-ui-next-attachment {
  border-right-width: 0;
  border-radius: 6px 0 0 6px;
  margin-right: 1.5em;
  right: -2px;
  transform: translateY(-50%) translateX(100%);
}
.review-ui-next-attachment:hover {
  margin-right: 0;
}
.review-ui-next-attachment .file-container {
  padding-right: var(--ink-u-spacing-m);
}
.review-ui-prev-attachment {
  border-left-width: 0;
  border-radius: 0 6px 6px 0;
  margin-left: 1.5em;
  left: -2px;
  transform: translateY(-50%) translateX(-100%);
}
.review-ui-prev-attachment:hover {
  margin-left: 0;
}
.review-ui-prev-attachment .file-container {
  padding-left: var(--ink-u-spacing-m);
}
/****************************************************************************
 * Entries (status updates, reviews, change descriptions)
 ****************************************************************************/
.review-request-page-entry {
  --rb-c-review-request-page-entry-content-bg: var(--if-light, #FFFFFF) var(--if-dark, var(--ink-p-container-bg));
  --rb-c-review-request-page-entry-content-bg-color: var(--if-light, #FFFFFF) var(--if-dark, var(--ink-p-container-bg));
  --rb-c-review-request-page-entry-content-border-color: var(--if-light, #C0C0C0) var(--if-dark, var(--ink-p-container-border-color));
  --rb-c-review-request-page-entry-content-collapsed-bg: var(--if-light, #ECECEE) var(--if-dark, var(--ink-p-container-bg));
  --rb-c-review-request-page-entry-content-collapsed-bg-color: var(--if-light, #ECECEE) var(--if-dark, var(--ink-p-container-bg));
  --rb-c-review-request-page-entry-content-collapsed-border-color: var(--if-light, #B1AFAF) var(--if-dark, var(--ink-p-container-border-color));
  clear: both;
  margin: 2rem 0;
}
@media screen and (max-width: 720px), screen and (max-device-width: 720px) and (orientation: landscape) {
  .review-request-page-entry {
    margin-top: 1rem;
  }
}
.review-request-page-entry:last-child {
  margin-bottom: 0;
}
.review-request-page-entry .collapse-button {
  border: 1px #333333 solid;
  display: inline-block;
  cursor: pointer;
  padding: 0;
}
.review-request-page-entry .collapse-button .rb-icon {
  vertical-align: top;
}
.review-request-page-entry-contents {
  background: var(--rb-c-review-request-page-entry-content-bg);
  border: var(--ink-u-border-thin) var(--rb-c-review-request-page-entry-content-border-color) solid;
  border-radius: 6px;
  box-shadow: 0px 2px 4px rgba(0, 0, 0, 0.1);
}
.review-request-page-entry-contents.collapsed {
  /*
     * Note that we use !important to ensure a consistent look for all
     * collapsed entries, regardless of their open state's styling.
     */
  background: var(--rb-c-review-request-page-entry-content-collapsed-bg) !important;
  border-color: var(--rb-c-review-request-page-entry-content-collapsed-border-color) !important;
}
.review-request-page-entry-contents.collapsed .body,
.review-request-page-entry-contents.collapsed .banners {
  display: none;
}
.review-request-page-entry-contents.collapsed .header {
  border-radius: 6px;
}
.has-avatar .review-request-page-entry-contents {
  margin-left: 80px;
  width: auto;
  position: relative;
}
.has-avatar .review-request-page-entry-contents:before,
.has-avatar .review-request-page-entry-contents:after {
  border: 1px transparent solid;
  content: " ";
  display: block;
  height: 0;
  left: -20px;
  position: absolute;
  right: 100%;
  top: 12px;
  width: 0;
}
.has-avatar .review-request-page-entry-contents:before {
  border-right-color: var(--rb-c-review-request-page-entry-content-border-color);
  border-width: 10px;
}
.has-avatar .review-request-page-entry-contents:after {
  border-right-color: var(--rb-c-review-request-page-entry-content-bg-color);
  border-width: 9px;
  margin-left: 2px;
  margin-top: 1px;
}
@media screen and (max-width: 720px), screen and (max-device-width: 720px) and (orientation: landscape) {
  .has-avatar .review-request-page-entry-contents {
    margin-left: 0;
    margin-top: 1em;
  }
  .has-avatar .review-request-page-entry-contents:after,
  .has-avatar .review-request-page-entry-contents:before {
    content: none;
  }
}
.has-avatar .review-request-page-entry-contents.collapsed:after {
  border-right-color: var(--rb-c-review-request-page-entry-content-collapsed-bg-color);
}
.has-avatar .review-request-page-entry-contents.collapsed:before {
  border-right-color: var(--rb-c-review-request-page-entry-content-collapsed-border-color);
}
.review-request-page-entry-contents .header {
  border-radius: 6px 6px 0 0;
  display: flex;
  align-items: baseline;
  gap: var(--ink-u-spacing-sm);
  padding: 12px;
}
.review-request-page-entry-contents .header a {
  color: inherit;
  text-decoration: none;
}
.review-request-page-entry-contents .banner {
  border-width: 0 0 1px 0;
  box-sizing: border-box;
  margin: 0;
  padding: 12px;
}
.review-request-page-entry-contents .banner.floating {
  border-top: 0;
  margin-top: 0;
}
.new-review-request-page-entry .review-request-page-entry-contents {
  border-color: #2278FC;
}
.new-review-request-page-entry .review-request-page-entry-contents:before {
  border-right-color: #2278FC;
}
/****************************************************************************
 * Reviews
 ****************************************************************************/
.review.has-draft .review-request-page-entry-contents:after {
  border-right-color: var(--rb-p-draft-bg);
}
.review.has-draft .header {
  background: var(--rb-p-draft-bg);
}
.review.has-draft .review-request-page-entry-contents:not(.collapsed) .header {
  /*
       * When the box is expanded, there's @review-request-entry-padding space
       * between the header and the banner. We take that space out of the header
       * instead of the banner to ensure that nothing jumps when the banner is
       * switching between fixed and floating modes.
       */
  padding-bottom: 0;
}
.review-comments {
  border: 0;
  list-style: none;
  margin: 0;
  padding: 0;
}
/*
 * An anchor beside a review box.
 *
 * This is used to help generate a link to a particular comment or reply on
 * a page. It will appear to the left of the review box, aligned with the
 * linked item, when hovering over the item.
 *
 * Consumers need to call ``.setup-floating-anchor()`` on the container that
 * should respond to the hover.
 */
.floating-anchor {
  box-sizing: border-box;
  display: none;
  position: absolute;
  top: 0;
  bottom: 0;
  text-align: right;
  padding-top: 1em;
  z-index: 20;
}
.floating-anchor a {
  color: #BBB;
  font-size: 120%;
  padding: 1em;
  text-decoration: none;
}
.floating-anchor a:hover {
  color: #888;
}
/**
 * Set up the floating anchor for a parent container.
 *
 * Args:
 *     container-offset-left (number):
 *          An additional offset to get the floating anchor's right-hand
 *          side to match the left-hand side of the review box. This should
 *          be the value of any parent container's padding.
 *
 *     margin-left (number):
 *          An additional margin to apply to the floating anchor. This is
 *          there to help nudge based on a pixel amount (for use in the left
 *          border for replies).
 */
/**
 * Set the offset for an existing floating anchor.
 *
 * Args:
 *     container-offset-left (number):
 *         The new offset for the floating anchor.
 *
 *     margin-left (number):
 *          An additional margin to apply to the floating anchor. This is
 *          there to help nudge based on a pixel amount (for use in the left
 *          border for replies).
 */
.review-comment-details {
  position: relative;
}
.review-comment-details:hover .floating-anchor {
  display: block;
}
@media screen and (max-width: 720px), screen and (max-device-width: 720px) and (orientation: landscape) {
  .review-comment-details .floating-anchor {
    /*
       * On mobile, we're going to show this on the right-hand side of the box
       * instead, optimistically.
       */
    left: auto;
    right: 0;
    padding-right: 0;
    margin-left: 0;
    width: auto;
  }
}
.review-comment-details .floating-anchor {
  left: -7em;
  width: 8em;
  padding-right: 0;
  margin-left: -1px;
}
@media screen and (max-width: 720px), screen and (max-device-width: 720px) and (orientation: landscape) {
  .review-comment-details .floating-anchor {
    margin-right: 1em;
  }
}
.has-avatar .review-comment-details .floating-anchor {
  left: -8em;
  width: 8em;
  padding-right: 0;
  margin-left: 0;
}
@media screen and (max-width: 720px), screen and (max-device-width: 720px) and (orientation: landscape) {
  .has-avatar .review-comment-details .floating-anchor {
    margin-right: 0;
  }
}
.review-comment-details .review-comment {
  padding: 2em;
}
.review-comment-details .review-comment .rb-c-issue-bar {
  margin-bottom: 2em;
}
.review-comment-details.comment-details-empty + .review-comment-thread .controls {
  margin-top: var(--ink-u-spacing-xl);
}
.review-comment-details.comment-details-empty .review-comment {
  padding: 0;
}
.review-comment-thread {
  padding: 0 2em 2em 2em;
}
.has-avatar .review-comment-thread .reply-comments > li .floating-anchor {
  left: -10em;
  width: 10em;
  padding-right: 2em;
  margin-left: -2px;
}
@media screen and (max-width: 720px), screen and (max-device-width: 720px) and (orientation: landscape) {
  .has-avatar .review-comment-thread .reply-comments > li .floating-anchor {
    margin-right: -2em;
  }
}
.review-comment-thread .controls {
  list-style: none;
  margin: 0;
  padding: 0;
  text-align: left;
}
.review-comment-thread .controls li {
  display: inline;
}
.review-comment-thread .reply-comments {
  margin: 0;
  padding: 0;
}
.review-comment-thread .reply-comments > li {
  border-left: 2px transparent solid;
  list-style: none;
  padding: 2em;
  position: relative;
  --rb-c-discussion-header-title-color: var(--ink-p-link-fg);
  /*
   * When there's a draft present, modify some colors so that it's apparent
   * that the comments are drafts, and modify margins so that the inline editor
   * opens without any jumps.
   */
}
.review-comment-thread .reply-comments > li.new-reply {
  border-left-color: #2278FC;
}
.review-comment-thread .reply-comments > li:hover .floating-anchor {
  display: block;
}
@media screen and (max-width: 720px), screen and (max-device-width: 720px) and (orientation: landscape) {
  .review-comment-thread .reply-comments > li .floating-anchor {
    /*
       * On mobile, we're going to show this on the right-hand side of the box
       * instead, optimistically.
       */
    left: auto;
    right: 0;
    padding-right: 0;
    margin-left: 0;
    width: auto;
  }
}
.review-comment-thread .reply-comments > li .floating-anchor {
  left: -9em;
  width: 9em;
  padding-right: 1em;
  margin-left: -3px;
}
@media screen and (max-width: 720px), screen and (max-device-width: 720px) and (orientation: landscape) {
  .review-comment-thread .reply-comments > li .floating-anchor {
    margin-right: -1em;
  }
}
.review-comment-thread .reply-comments > li .rb-c-discussion-header {
  margin-bottom: 1em;
}
.review-comment-thread .reply-comments > li.draft {
  --rb-c-discussion-header-title-color: var(--rb-p-draft-label-fg);
  --textarea-offset-horiz: calc(var(--rb-c-textarea-spacing) + var(--ink-u-border-thin));
  --textarea-offset-vert: calc(2 * var(--rb-c-textarea-spacing) + var(--ink-u-border-thin));
}
.review-comment-thread .reply-comments > li.draft .rb-c-discussion-header {
  margin-bottom: var(--textarea-offset-vert);
}
.review-comment-thread .reply-comments > li.draft .rb-c-discussion-header label a {
  color: var(--rb-p-draft-label-fg);
}
.review-comment-thread .reply-comments > li.draft .rb-c-text-editor {
  margin: calc(var(--rb-c-textarea-spacing) - var(--textarea-offset-vert)) calc(-1 * var(--textarea-offset-horiz)) 0 calc(-1 * var(--textarea-offset-horiz));
}
pre.reviewtext {
  white-space: pre-wrap;
}
#reviews .box-statuses {
  float: left;
  text-align: center;
}
@media screen and (max-width: 720px), screen and (max-device-width: 720px) and (orientation: landscape) {
  #reviews .box-statuses {
    margin-top: 3em;
    float: none;
  }
}
#reviews .box-statuses .box-status {
  position: relative;
  transition: 0.2s linear all;
}
#reviews .box-statuses .box-status.has-issues.revoking-ship-it .ship-it-label,
#reviews .box-statuses .box-status.has-issues.ship-it:hover .ship-it-label {
  top: 23px;
}
#reviews .box-statuses .box-status.has-issues .avatar-container {
  border-color: #caad00;
}
#reviews .box-statuses .box-status.ship-it .avatar-container {
  border-color: #6ebf20;
}
#reviews .box-statuses .box-status.ship-it.has-issues .avatar-container {
  border-color: #caad00;
}
#reviews .box-statuses .box-status.ship-it.has-issues .fix-it-label {
  z-index: 1;
}
#reviews .box-statuses .box-status.ship-it.has-issues .ship-it-label {
  top: 3px;
  margin-left: 2px;
  padding-left: 2px;
  padding-right: 2px;
}
#reviews .box-statuses .box-status .avatar-container {
  background: var(--ink-p-surface-bg);
  border: 2px var(--ink-p-container-border-color) dotted;
  border-radius: 50%;
  overflow: hidden;
  width: 48px;
  height: 48px;
  margin: 0 9px;
  transition: border-color 0.4s ease-in-out;
}
@media screen and (max-width: 720px), screen and (max-device-width: 720px) and (orientation: landscape) {
  #reviews .box-statuses .box-status .avatar-container {
    display: inline-block;
    vertical-align: top;
  }
}
#reviews .box-statuses .box-status .avatar-container img {
  border: 2px transparent solid;
  box-sizing: border-box;
}
#reviews .box-statuses .box-status .labels-container {
  margin-top: -5px;
  position: relative;
}
@media screen and (max-width: 720px), screen and (max-device-width: 720px) and (orientation: landscape) {
  #reviews .box-statuses .box-status .labels-container {
    display: inline-block;
    margin-top: 0;
    top: 4px;
  }
}
#reviews .box-statuses .box-status label {
  border: 1px #888888 solid;
  border-radius: 6px;
  color: var(--ink-p-fg-on-light);
  display: block;
  line-height: 1.5;
  margin-bottom: 1.5em;
  padding: 2px 4px;
  position: absolute;
  left: 0;
  top: 0;
  width: 5.5em;
}
@media screen and (max-width: 720px), screen and (max-device-width: 720px) and (orientation: landscape) {
  #reviews .box-statuses .box-status label {
    margin-bottom: 0;
  }
}
#reviews .box-statuses .box-status label.fix-it-label,
#reviews .box-statuses .box-status label.ship-it-label {
  transition-delay: 0.2s;
}
#reviews .box-statuses .box-status label.ship-it-label {
  border: 1px #489300 solid;
  background: #aeff60;
  position: absolute;
  transition: padding 0.2s ease-in-out, top 0.2s ease-in-out, margin 0.2s ease-in-out, left 0.5s ease-in-out, opacity 0.8s ease;
}
#reviews .box-statuses .box-status label.ship-it-label .revoke-ship-it {
  cursor: pointer;
  font-size: 110%;
  margin-left: 0.1em;
  opacity: 0.35;
  transition: opacity 0.2s ease;
}
#reviews .box-statuses .box-status label.ship-it-label .revoke-ship-it:hover {
  opacity: 1;
}
#reviews .box-statuses .box-status label.fix-it-label {
  border: 1px #b09700 solid;
  background: #FFF4B0;
  transition: left 0.5s ease-in-out, opacity 0.8s ease;
}
#reviews .box-statuses .box-status label.fix-it-label .open-issue-count {
  color: darkred;
  display: block;
}
#reviews .review .body {
  clear: both;
}
#view_controls {
  list-style: none;
  margin: 2em 0;
  text-align: center;
}
#view_controls a,
#view_controls button {
  background: #E0E0E0;
  border: 1px #C3C3C3 solid;
  border-radius: 6px;
  color: black;
  display: inline-block;
  font-size: inherit;
  padding: 0.6em 1em;
  text-decoration: none;
}
#view_controls a:hover,
#view_controls button:hover {
  background: #ECECEC;
}
#view_controls li {
  display: inline-block;
  margin: 1em;
  padding: 0;
}
#view_controls .rb-icon {
  vertical-align: top;
}
.sidebyside.loading tbody {
  background-color: #F3F3F3;
  padding: 2px 2px 1px 2px;
}
.sidebyside.loading tbody td {
  padding: 4px;
  font-size: 20px;
  text-align: center;
}
/****************************************************************************
 * Change Descriptions
 ****************************************************************************/
.changedesc {
  --rb-c-review-request-page-entry-content-bg-color: var(--if-light, #fffef8) var(--if-dark, var(--rb-c-review-request-bg-color));
  --rb-c-review-request-page-entry-content-bg: var(--rb-c-review-request-page-entry-content-bg-color);
  --rb-c-review-request-page-entry-content-border-color: var(--if-light, #CABF71) var(--if-dark, var(--rb-c-review-request-border-color));
  --rb-c-review-request-page-entry-content-collapsed-bg-color: var(--if-light, #eceadd) var(--if-dark, var(--ink-p-cool-grey-100));
  --rb-c-review-request-page-entry-content-collapsed-bg: var(--rb-c-review-request-page-entry-content-collapsed-bg-color);
}
/****************************************************************************
 * Review Dialog
 ****************************************************************************/
#review-form {
  overflow: auto;
  margin: 0;
  padding: 20px;
}
#review-form label[for="id_shipit"] {
  font-weight: bold;
}
#review-form #id_shipit,
#review-form label[for="id_shipit"] {
  vertical-align: middle;
}
#review-form .add-link {
  font-size: 110%;
}
#review-form .add-link:visited {
  color: var(--ink-p-link-fg);
}
#review-form .delete-comment {
  color: var(--ink-p-fg);
}
#review-form .comment-label {
  display: block;
  line-height: 16px;
  vertical-align: top;
  color: var(--rb-p-draft-label-fg);
  display: flex;
  justify-items: center;
  font-size: 1.1em;
  font-weight: bold;
  margin: 0 0 var(--ink-u-spacing-l) 0;
  text-decoration: none;
}
#review-form .edit-field > * {
  vertical-align: middle;
}
#review-form .edit-field .comment-label {
  margin-right: var(--ink-u-spacing-ml);
}
#review-form .edit-fields {
  display: flex;
  flex-direction: column;
  gap: var(--ink-u-spacing-l);
}
#review-form #review-form-comments {
  background: none;
  display: flex;
  flex-direction: column;
  position: relative;
  gap: var(--ink-u-spacing-xl);
  /* Don't incorporate empty elements into the gap calculations. */
}
#review-form #review-form-comments > :empty {
  display: none !important;
}
#review-form #review-form-comments pre {
  white-space: pre-wrap;
}
#review-form #review-form-comments .rb-c-review-comment-thumbnail {
  margin: 0 -20px var(--ink-u-spacing-l) -20px;
}
#review-form #review-form-comments .review-comments {
  display: flex;
  flex-direction: column;
  gap: inherit;
  list-style: none;
  margin: 0;
  padding: 0;
}
#review-form #review-form-comments .review-comments > li {
  margin: 0;
  padding: 0;
  --rb-c-discussion-header-title-color: var(--ink-p-link-fg);
  /*
   * When there's a draft present, modify some colors so that it's apparent
   * that the comments are drafts, and modify margins so that the inline editor
   * opens without any jumps.
   */
}
#review-form #review-form-comments .review-comments > li .rb-c-discussion-header {
  margin-bottom: 1em;
}
#review-form #review-form-comments .review-comments > li.draft {
  --rb-c-discussion-header-title-color: var(--rb-p-draft-label-fg);
  --textarea-offset-horiz: calc(var(--rb-c-textarea-spacing) + var(--ink-u-border-thin));
  --textarea-offset-vert: calc(2 * var(--rb-c-textarea-spacing) + var(--ink-u-border-thin));
}
#review-form #review-form-comments .review-comments > li.draft .rb-c-discussion-header {
  margin-bottom: var(--textarea-offset-vert);
}
#review-form #review-form-comments .review-comments > li.draft .rb-c-discussion-header label a {
  color: var(--rb-p-draft-label-fg);
}
#review-form #review-form-comments .review-comments > li.draft .rb-c-text-editor {
  margin: calc(var(--rb-c-textarea-spacing) - var(--textarea-offset-vert)) calc(-1 * var(--textarea-offset-horiz)) 0 calc(-1 * var(--textarea-offset-horiz));
}
#review-form #review-form-comments .spinner {
  font-size: 20px;
}
#review-form #review-form-comments .delete-comment {
  display: inline-block;
  margin-left: 0.5em;
}
#review-form #show-review-tips {
  float: right;
}
#review-form .rb-c-slideshow__nav {
  align-items: center;
  display: flex;
  margin: -3px 0 0 0;
  text-align: left;
}
#review-form .rb-c-slideshow__nav label {
  font-weight: bold;
  padding-right: 0.5em;
}
#review-form .rb-c-slideshow__nav a,
#review-form .rb-c-slideshow__nav a:active,
#review-form .rb-c-slideshow__nav a:visited {
  color: black;
  text-decoration: none;
  font-size: 140%;
}
#review-form-modalbox .modalbox-buttons {
  left: 0;
}
#review-form-modalbox .modalbox-buttons .review-dialog-buttons-left {
  /*
       * We're only absolutely positioning the buttons-left and not
       * buttons-right. This way, buttons-right dictates the height, and
       * buttons-left is able to fit in on the same row.
       */
  position: absolute;
  left: 0;
  margin-left: 0;
}
#review-form-modalbox .modalbox-buttons .review-dialog-buttons-left > :first-child {
  margin-left: 0;
}
@media screen and (max-width: 720px), screen and (max-device-width: 720px) and (orientation: landscape) {
  #review-form-modalbox .modalbox-buttons .review-dialog-buttons-left {
    position: relative;
  }
  #review-form-modalbox .modalbox-buttons .review-dialog-buttons-left,
  #review-form-modalbox .modalbox-buttons .review-dialog-buttons-right {
    display: inline;
  }
}
/****************************************************************************
 * Uploaded files
 ****************************************************************************/
/**
 * A container for a file attachment.
 *
 * Structure:
 *     <div class="file-container">
 *      <div class="file">...</div>
 *     </div>
 */
.file-container {
  float: left;
  /**
   * A file attachment.
   *
   * Structure:
   *     <div class="file">...</div>
   *      <div class="file-actions-container">...</div>
   *      <div class="file-state-container">...</div>
   *      <div class="file-thumbnail-container">...</div>
   *      <div class="file-caption-container">...</div>
   *     </div>
   */
  /**
   * A container for the file attachment state label.
   *
   * Structure:
   *     <div class="file-state-container">
   *      <div class="rb-c-field-state-label">...</div>
   *     </div>
   */
}
.file-container.-is-loading {
  opacity: 0.5;
}
.file-container.editing .file .file-caption-container {
  opacity: 1;
}
@media only screen and (max-width: 800px) {
  .file-container {
    float: none;
  }
}
.file-container .file:hover .file-actions-container {
  display: block;
}
.file-container .file {
  border: 1px var(--ink-p-container-border-color) solid;
  box-shadow: 0px 2px 4px rgba(0, 0, 0, 0.1);
  box-sizing: border-box;
  display: block;
  position: relative;
  margin: 1em 1.5em 0.5em 0;
  max-width: 300px;
  transition: 0.2s opacity linear;
  width: 300px;
  /*
     * This container provides the padding necessary to display a shadow
     * around all but one edges of the actions list. We clip the shadow on
     * the side sharing a border with the file attachment thumbnail.
     */
}
@media screen and (max-width: 720px), screen and (max-device-width: 720px) and (orientation: landscape) {
  .file-container .file {
    margin: 1.5em 0 0 0;
  }
}
.file-container .file .djblets-o-spinner {
  font-size: 37.5px;
  margin-top: 1em;
  opacity: 0.5;
}
.file-container .file .file-actions-container {
  display: none;
  overflow: hidden;
  padding: 4px;
  position: absolute;
  left: 100%;
  top: -5px;
  z-index: 110;
}
.file-container .file .file-actions-container.left {
  padding-right: 0;
}
.file-container .file .file-actions-container.left .file-actions {
  border-right-color: var(--if-dark, transparent) var(--if-light, #EEEEEE);
  margin-left: 4px;
}
.file-container .file .file-actions-container.right {
  padding-left: 0;
}
.file-container .file .file-actions-container.right .file-actions {
  border-left-color: var(--if-dark, transparent) var(--if-light, #EEEEEE);
}
@media only screen and (max-width: 800px) {
  .file-container .file .file-actions-container {
    left: -5px;
    top: 146px;
    width: 300px;
  }
}
.file-container .file .file-actions {
  background-color: var(--if-dark, var(--ink-p-cool-grey-100)) var(--if-light, #FCFCFC);
  border: 1px var(--ink-p-container-border-color) solid;
  box-shadow: 0px 2px 4px rgba(0, 0, 0, 0.1);
  box-sizing: border-box;
  list-style: none;
  margin: 0;
  min-height: 119px;
  padding: 0;
  white-space: nowrap;
}
.file-container .file .file-actions li {
  margin: 0;
  padding: 0;
}
.file-container .file .file-actions li a {
  color: var(--ink-p-fg);
  display: block;
  padding: 0.5em 1em;
  text-decoration: none;
}
.file-container .file .file-actions li a:hover {
  background: var(--ink-p-accent-primary-bg);
  color: var(--ink-p-accent-primary-fg);
}
.file-container .file .file-thumbnail-container {
  background: var(--rb-theme-diff-equals-bg);
  color: var(--rb-theme-diff-equals-fg);
  height: 150px;
  text-align: center;
}
.file-container .file .file-thumbnail-container a {
  color: inherit;
  text-decoration: none;
}
.file-container .file .file-thumbnail-container pre {
  font-size: x-small;
}
.file-container .file .file-thumbnail-container .file-thumbnail-overlay {
  box-sizing: border-box;
  max-height: 150px;
  max-width: 100%;
  margin: 0;
  padding: 0;
  position: absolute;
  left: 0;
  width: 100%;
  height: 100%;
  z-index: 30;
}
.file-container .file .file-thumbnail-container .file-thumbnail {
  box-sizing: border-box;
  max-height: 150px;
  max-width: 100%;
  margin: 0;
  padding: 0;
  border: 0;
  overflow: hidden;
  text-align: center;
  white-space: nowrap;
  vertical-align: middle;
  margin: auto;
}
.file-container .file .file-thumbnail-container .file-thumbnail-clipped {
  border: 0;
  overflow: hidden;
  text-align: left;
  padding: 1em 0 0 1em;
  font-size: 8pt;
  /* Override the styling used for the <pre>s for fields. */
}
.file-container .file .file-thumbnail-container .file-thumbnail-clipped pre {
  background-color: transparent;
  border: 0;
  margin: 0;
  padding: 0;
}
.file-container .file .file-caption-container {
  opacity: 0.9;
  background: var(--if-dark, var(--ink-p-cool-grey-100)) var(--if-light, #FCFCFC);
  border-top: 1px var(--if-dark, transparent) var(--if-light, #EEEEEE) solid;
  bottom: 0;
  box-sizing: border-box;
  line-height: 2.5em;
  padding: 0 30px;
  position: absolute;
  text-align: center;
  z-index: 31;
  max-width: 298px;
  width: 298px;
}
.file-container .file .file-caption-container a {
  color: inherit;
  text-decoration: none;
}
.file-container .file .file-caption-container a.empty-caption {
  color: var(--ink-p-fg-weak);
  font-style: italic;
}
.file-container .file .file-caption-container .file-caption {
  /* Ellipsize the text contents. */
  overflow: hidden;
  white-space: nowrap;
  text-overflow: ellipsis;
  opacity: 1;
  line-height: 31px;
  height: 31px;
  text-shadow: 0px 0px 2px var(--if-dark, black) var(--if-light, white);
}
.file-container .file .file-caption-container .rb-c-inline-editor {
  display: flex;
  flex-direction: column;
  position: absolute;
  gap: 0;
  width: 300px;
  z-index: 20;
  /* Line up with .file's side borders. */
  margin-left: -31px;
}
.file-container .file .file-caption-container .rb-c-inline-editor__actions {
  /*
         * This provides enough padding to cleanly cover much of any file
         * attachment's header below.
         */
  background: var(--if-dark, var(--ink-p-cool-grey-100)) var(--if-light, #FCFCFC);
  border: 1px var(--ink-p-container-border-color) solid;
  border-top: 0;
  border-radius: 0 0 6px 6px;
  box-shadow: 0px 2px 4px rgba(0, 0, 0, 0.1);
  justify-content: center;
  padding: 5px 0;
}
.file-container .file .file-caption-container .rb-c-inline-editor__field > input[type='text'] {
  background: transparent;
  border: 0;
  border-radius: 0;
  font-family: inherit;
  font-size: inherit;
  height: 31px;
  margin: 0;
  text-align: inherit;
  vertical-align: bottom;
  /*
         * The 4px is needed to align the input with the text. It matches
         * the margin between the text and pencil.
         */
  padding: 0 4px 0 0;
  /*
         * The box shadow doesn't display correctly in file attachment
         * thumbnails, so hide it. There will be a red background instead.
         */
}
.file-container .file .file-caption-container .rb-c-inline-editor__field > input[type='text']:focus {
  outline: 0;
}
.file-container .file .file-caption-container .rb-c-inline-editor__field > input[type='text']:not(:focus) {
  background: rgba(255, 0, 0, 0.15);
  box-shadow: none;
}
.file-container .file .file-caption-container .rb-c-inline-editor__field > input[type='text']::-ms-clear {
  display: none;
}
.file-container .file .file-caption-container .rb-icon-edit {
  vertical-align: middle;
  position: absolute;
  right: 6px;
  bottom: 6px;
}
.file-container .file-state-container {
  cursor: default;
  padding: 0.5em;
  position: absolute;
  right: 0;
  z-index: 31;
}
/****************************************************************************
 * Screenshots
 ****************************************************************************/
.screenshot-caption {
  background-color: #F6F6F6;
  border: 1px #999999 solid;
  border-top: 1px #CCCCCC solid;
  padding: 2px 8px;
  border-radius: 0 0 6px 6px;
}
.screenshot-caption img {
  vertical-align: bottom;
}
.screenshot-container {
  background: white;
  float: left;
  display: inline;
  margin-bottom: 10px;
  margin-right: 10px;
  max-width: 400px;
  min-width: 130px;
  text-align: center;
  overflow: hidden;
  vertical-align: middle;
  position: relative;
  border-radius: 6px;
}
.screenshot-container:hover {
  background-color: #F6F6F6;
}
.screenshot-container:hover .screenshot-caption {
  background-color: #E6E6E6;
}
.screenshot-container a {
  color: black;
  text-decoration: none;
}
.screenshot-container .image {
  border: 1px #999999 solid;
  border-bottom: 0;
  border-radius: 6px 6px 0 0;
  cursor: pointer;
  height: 100px;
  line-height: 100px;
  margin: 0 auto;
  vertical-align: bottom;
}
.screenshot-container .image img {
  border-radius: 5px 5px 0 0;
  vertical-align: middle;
}
/****************************************************************************
 * Screenshot Thumbnails
 ****************************************************************************/
#screenshot-thumbnails {
  margin: 2px;
  padding: 0.5em;
}
#screenshot-thumbnails.dragover {
  border: 2px green dashed;
  display: block;
  margin: 0;
}
/****************************************************************************
 * List of Attached Files
 ****************************************************************************/
#file-list-container.dnd-overlay-visible {
  display: block !important;
  margin: 0;
  /*
   * If there are no file attachments present when showing the drag and drop
   * overlay, this will default to being very short. Force it to be a minimum
   * height to give it enough heft to be a useful drop point.
   */
  min-height: 64px;
}
#file-list {
  margin: 0;
  padding: 0;
  /*
   * When hovering over a thumbnail, fade out all the other thumbnails, to both
   * provide focus to the thumbnail the user is hovering over, and to help
   * separate out the actions menu from other thumbnail contents.
   */
}
#file-list .file-container:not(.editing) .file.faded {
  opacity: 0.5;
}
#file-list h1.drop-indicator {
  clear: both;
  text-align: center;
}
/****************************************************************************
 * Comment detail dialog
 ****************************************************************************/
.comment-dlg {
  border: 1px var(--rb-p-draft-border-color) solid;
  border-radius: var(--ink-u-border-radius-std);
  box-shadow: var(--ink-g-shadow-std);
  box-sizing: border-box;
  cursor: default;
  margin-top: 8px;
  overflow: hidden;
  position: absolute;
  max-width: calc(100vw - 2em);
  max-height: calc(100vh - 2em);
  z-index: var(--ink-z-dialog);
}
.comment-dlg form {
  background: var(--rb-p-draft-bg);
  display: block;
  padding: 6px;
  max-width: 100%;
}
.comment-dlg form .buttons {
  margin: 0;
}
.comment-dlg form .buttons input[type="button"] {
  margin-right: 3px;
}
.comment-dlg h1 {
  background: transparent;
  border: 0;
  margin: 0;
  padding: 0;
}
.comment-dlg img.ui-resizable-grip {
  /* Use -1 for bottom and right so it overlaps the resize borders. */
  bottom: -1px;
  cursor: se-resize;
  padding: 0.5em;
  position: absolute;
  right: -1px;
  z-index: 20;
}
.comment-dlg .comment-dlg-body,
.comment-dlg .comment-dlg-footer,
.comment-dlg .comment-dlg-header {
  position: relative;
}
.comment-dlg .comment-dlg-header,
.comment-dlg .other-comments-header {
  cursor: move;
}
.comment-dlg .comment-dlg-footer {
  padding: 6px 0 0 0;
}
.comment-dlg .comment-dlg-footer .status {
  display: none;
  font-style: italic;
  margin-bottom: 6px;
}
.comment-dlg .comment-dlg-header {
  padding: 0 0 6px 0;
  line-height: 16px;
}
.comment-dlg .comment-dlg-header .markdown-info {
  line-height: inherit;
}
.comment-dlg .comment-dlg-options {
  list-style: none;
  margin: 0;
  padding: 6px 0 0 0;
}
.comment-dlg .comment-dlg-options li {
  display: flex;
  align-items: center;
  margin: 3px 0;
  padding: 0;
}
.comment-dlg .comment-dlg-options li:first-child {
  margin-top: 0;
}
.comment-dlg .comment-dlg-options li:last-child {
  margin-bottom: 0;
}
.comment-dlg .comment-dlg-options li > input:not(:first-child) {
  margin-left: var(--ink-u-spacing-l);
}
.comment-dlg .markdown-info {
  line-height: 16px;
}
.comment-dlg .other-comments {
  background: var(--if-dark, var(--ink-p-cool-grey-500)) var(--if-light, #A1C0E3);
  border-right: 1px var(--if-dark, rgba(0, 0, 0, 0.5)) var(--if-light, #49BB18) solid;
  padding: 6px;
}
.comment-dlg .other-comments .other-comments-header {
  padding-bottom: 2px;
}
.comment-dlg .other-comments ul {
  background: var(--ink-c-data-table-body-bg);
  border: 1px #333333 solid;
  list-style: none;
  /*
       * This plus the padding on .other-comments-header gives the header a
       * total bottom "padding" equal to @comment-dlg-padding. The top margin
       * here has to be 2px less than @comment-dlg-padding, otherwise the
       * bottom margin for .other-comments box is too small.
       */
  margin: 4px 0 0 0;
  overflow: auto;
  padding: 0;
  position: relative;
}
.comment-dlg .other-comments ul li {
  padding: 6px;
}
.comment-dlg .other-comments ul li.even {
  background: var(--ink-c-data-table-row-alt-bg);
}
.comment-dlg .other-comments ul li.odd {
  background: var(--ink-c-data-table-row-bg);
}
.comment-dlg .other-comments ul li h2 {
  font-size: 90%;
  margin: 0 0 6px 0;
  padding: 0;
}
.comment-dlg .other-comments ul li h2 .actions {
  font-weight: normal;
  right: 6px;
}
.comment-dlg .other-comments ul li h2 .actions a {
  margin-left: 6px;
  padding: 3px;
}
.comment-dlg .other-comments ul li pre {
  white-space: pre-wrap;
  font-size: 90%;
}
.comment-dlg .rb-c-text-editor {
  margin: 0;
}
.comment-dlg .ui-icon-gripsmall-diagonal-se {
  background: url('../../images/resize-grip.png') no-repeat top left;
}
/****************************************************************************
 * Banners
 ****************************************************************************/
#review-banner {
  overflow: hidden;
}
#review-banner.hidden {
  max-height: 0;
  visibility: hidden;
}
#review-banner.hidden .banner {
  /*
       * Instead of hiding the banner, we keep the position off-screen by
       * default using a transform. This makes it easy to animate it on-screen
       * when putting it in the "shown" state.
       */
  transform: translateY(-100%);
}
#review-banner.ui-ready {
  transition: max-height 0.3s linear, visibility 0.3s linear;
}
#review-banner.ui-ready .banner {
  /*
       * We only set the position as fixed when the UI is ready (JavaScript
       * has processed things). The reason for this is that when the page is
       * loading, we want the #review-banner to have the same height as the
       * draft banner, but the JavaScript wouldn't have executed yet, so it
       * wouldn't be able to force that height. So instead, we leave the
       * banner with a normal position, impacting #review-banner's height,
       * and ensuring the page doesn't jump. Then we convert it to fixed once
       * we've rendered everything.
       */
  position: fixed;
  left: 0;
  top: 0;
  transition: transform 0.3s linear;
}
#review-banner .banner {
  border-left: 0;
  border-right: 0;
  border-top: 0;
  box-shadow: 0px 2px 4px rgba(0, 0, 0, 0.1);
  margin: 0;
  width: 100%;
  z-index: 100;
}
/****************************************************************************
 * Tooltips
 ****************************************************************************/
.tooltip {
  background-color: #fef6b3;
  border: 1px #a58600 solid;
  border-radius: var(--ink-u-border-radius-m);
  color: var(--ink-p-fg-on-light);
  overflow: hidden;
  padding: var(--ink-u-spacing-m);
  position: absolute;
  max-width: 60em;
  z-index: calc(var(--ink-z-event-overlay) + 1);
}
.tooltip.comments {
  border: 1px var(--ink-p-black) solid;
  border-bottom: 0;
  padding: 0;
  min-width: 25em;
}
.tooltip.comments > ul {
  list-style: none;
  margin: 0;
  padding: 0;
}
.tooltip.comments > ul > li {
  background-color: var(--rb-p-flag-published-bg);
  border-bottom: 1px var(--ink-p-light__blue-600) solid;
  display: flex;
  flex-direction: column;
  gap: inherit;
  margin: 0;
  padding: var(--ink-u-spacing-m);
}
.tooltip.comments > ul > li.draft {
  background-color: var(--rb-p-flag-draft-bg);
  border-bottom: 1px var(--rb-p-flag-draft-border-color) solid;
}
.tooltip.comments > ul > li div.reviewer {
  font-weight: bold;
  margin-bottom: 1em;
}
.tooltip.comments > ul > li pre {
  font-size: 8pt;
  margin: 0;
  padding: 0;
  white-space: pre-wrap;
}
.tooltip.comments > ul > li .rich-text {
  line-height: 1.2;
}
.tooltip.comments > ul > li .rich-text .codehilite {
  background: #FBFAF8;
  color: var(--ink-p-fg-on-light);
  margin: 0 calc(-1 * var(--ink-u-spacing-m));
  padding: var(--ink-u-spacing-xs) var(--ink-u-spacing-m);
}
.tooltip.comments > ul > li .rich-text .codehilite:before {
  border-left: 0;
  border-right: 0;
  border-radius: 0;
  left: 0;
  right: 0;
}
/****************************************************************************
 * Bubbles
 ****************************************************************************/
.bubble {
  background-color: white;
  border: 1px black solid;
  border-radius: 8px;
  color: var(--ink-p-fg-on-light);
  font-size: 10pt;
  font-weight: bold;
  padding: 6px;
  position: absolute;
  white-space: nowrap;
  z-index: 120;
}
/****************************************************************************
 * "Update Diff" dialog
 ****************************************************************************/
.update-diff {
  width: 60em;
  height: 16em;
}
.update-diff #error-contents,
.update-diff #parent-diff-error-contents {
  margin: 0 5em;
}
.update-diff .input {
  height: 16em;
  line-height: 16em;
  margin: 2em 2em 6em 2em;
  border: 1px solid #C0C0C0;
}
.update-diff #processing-diff .spinner,
.update-diff #uploading-diffs .spinner {
  width: 16px;
  height: 16px;
  font-size: 16px;
  margin: auto;
}
.update-diff #error-contents,
.update-diff #parent-diff-error-contents {
  line-height: 12pt;
  margin-bottom: 1em;
  position: relative;
}
.update-diff #error-contents img,
.update-diff #parent-diff-error-contents img {
  margin-right: 5px;
  vertical-align: sub;
}
.update-diff .input {
  border-radius: 6px;
  position: relative;
  text-align: center;
  vertical-align: middle;
}
.update-diff .input > form {
  display: flex;
  align-items: center;
  justify-content: center;
  gap: 1ch;
}
.update-diff .input .startover {
  position: absolute;
  bottom: 0;
  right: 5px;
  line-height: 14pt;
}
.update-diff .drag-hover {
  box-shadow: inset 0px 2px 4px rgba(0, 0, 0, 0.1);
}
/****************************************************************************
 * Status Updates
 ****************************************************************************/
#initial-status-updates .header {
  border-width: 0 0 1px 0;
}
#initial-status-updates .review-request-page-entry-contents {
  overflow: hidden;
}
#initial-status-updates .review-request-page-entry-contents.collapsed .header {
  background: var(--rb-c-review-request-page-entry-content-collapsed-bg);
  border-width: 0;
}
.status-update-review-header {
  border-width: 1px 0;
  margin: 0.75rem 0 -1px;
  padding: 6px 12px;
}
#initial-status-updates .header,
.status-update-review-header {
  --_status-update-review-header-bg-light: var(--ink-p-container-bg);
  --_status-update-review-header-border-color: var(--ink-p-container-border-color);
  --_status-update-review-header-text-color: var(--ink-p-container-fg);
  background: var(--if-dark, var(--ink-p-container-bg)) var(--if-light, var(--_status-update-review-header-bg-light));
  border: var(--ink-u-border-thin) rgba(0, 0, 0, 0.2) solid;
  border-left: 0;
  border-right: 0;
  color: var(--_status-update-review-header-text-color);
}
#initial-status-updates .header.status-update-state-failure,
.status-update-review-header.status-update-state-failure {
  --_status-update-review-header-bg-light: var(--ink-p-accent-error-bg);
  --_status-update-review-header-text-color: var(--if-dark, var(--rb-c-status-updates-failure-text-color)) var(--if-light, var(--ink-p-accent-error-fg));
}
#initial-status-updates .header.status-update-state-pending,
.status-update-review-header.status-update-state-pending {
  --_status-update-review-header-bg-light: var(--ink-p-accent-highlight-bg);
  --_status-update-review-header-text-color: var(--if-dark, var(--ink-p-accent-highlight-fg-on-container)) var(--if-light, var(--ink-p-accent-highlight-fg));
}
#initial-status-updates .header.status-update-state-not-yet-run,
.status-update-review-header.status-update-state-not-yet-run {
  --_status-update-review-header-bg-light: var(--ink-p-cyan-100);
  --_status-update-review-header-text-color: var(--if-dark, var(--rb-c-status-updates-not-yet-run-text-color)) var(--if-light, var(--ink-p-accent-highlight-fg));
}
#initial-status-updates .header.status-update-state-success,
.status-update-review-header.status-update-state-success {
  --_status-update-review-header-bg-light: var(--ink-p-accent-success-bg);
  --_status-update-review-header-text-color: var(--if-dark, var(--ink-p-accent-success-fg-on-container)) var(--if-light, var(--ink-p-accent-success-fg));
}
.status-update-review .banner {
  border-bottom-width: 0;
  margin-top: 1px;
}
.status-update-review .banner.floating {
  border-bottom-width: 1px;
}
.status-update-summary-entry {
  line-height: 20px;
  padding: 12px;
  vertical-align: middle;
}
.status-update-summary-entry::before {
  font-size: 20px;
  font-family: FontAwesome;
  /* Set this up to allow for animations. We need position: absolute. */
  position: absolute;
}
.status-update-summary-entry.status-update-state-failure {
  color: var(--rb-c-status-updates-failure-text-color);
}
.status-update-summary-entry.status-update-state-failure::before {
  content: "\f057";
}
.status-update-summary-entry.status-update-state-pending {
  color: var(--rb-c-status-updates-pending-text-color);
}
.status-update-summary-entry.status-update-state-pending::before {
  animation: fa-spin 1.5s infinite linear;
  content: "\f021";
  /*
       * NOTE: We're trying to get the center point of this character,
       *       but realistically this is a flawed approach. We should move
       *       to a SVG.
       */
  width: 17px;
  height: 20px;
}
.status-update-summary-entry.status-update-state-not-yet-run {
  color: var(--rb-c-status-updates-not-yet-run-text-color);
}
.status-update-summary-entry.status-update-state-not-yet-run::before {
  content: "\f04c";
}
.status-update-summary-entry.status-update-state-success {
  color: var(--rb-c-status-updates-success-text-color);
}
.status-update-summary-entry.status-update-state-success::before {
  content: "\f058";
}
.status-update-summary-entry .fa {
  margin-right: 0.5em;
}
.status-update-summary-entry .status-update-request-run {
  margin-left: 1em;
  margin-top: -5px;
}
.status-update-summary-entry .summary {
  font-weight: bold;
  /* This will cover the icon with spacing after. */
  margin-left: 25px;
}
.status-update-summary-entry a {
  float: right;
}
/*
 * Any changes to this need to be reflected in _resizeLayout in
 * reviewRequestEditorView.js
 */
:root,
.rb-c-review-request {
  /* Review request variables. */
  --rb-c-review-request-bg-color: var(--if-light, #FEFADF) var(--if-dark, var(--ink-p-cool-grey-200));
  --rb-c-review-request-bg: var(--if-light, linear-gradient(to bottom, #FFFDF3, #FEFADF)) var(--if-dark, var(--rb-c-review-request-bg-color));
  --rb-c-review-request-border-color: var(--if-light, #BCA626) var(--if-dark, var(--ink-p-cool-grey-300));
  --rb-c-review-request-border-radius: var(--ink-u-border-radius-std);
  --rb-c-review-request-border: 1px var(--rb-c-review-request-border-color) solid;
  /* Review request action bar variables. */
  --rb-c-review-request-actions-bg: var(--ink-p-header-bg);
  --rb-c-review-request-actions-active-bg: var(--if-light, #FFFDF3) var(--if-dark, var(--rb-c-review-request-bg-color));
  --rb-c-review-request-actions-hover-bg: var(--if-light, #d9c581) var(--if-dark, rgba(0, 0, 0, 0.2));
  --rb-c-review-request-actions-border: var(--rb-c-review-request-border);
  --rb-c-review-request-actions-text-color: var(--ink-p-header-fg);
}
/****************************************************************************
 * Review request box
 ****************************************************************************/
/**
 * Information and fields for a review request.
 *
 * This manages the structure of the review request box, used on the review
 * request page, diff viewer, and review UI pages.
 *
 * This may also be mixed into ``review-ui-box``, providing additional elements.
 *
 * Version Added:
 *     6.0
 *
 * DOM Attributes:
 *     aria-label (string):
 *         A string describing that this is the review request information.
 *
 * Structure:
 *     <section class="rb-c-review-request">
 *      <div class="rb-c-review-request__header">...</div>
 *      <div class="rb-c-review-request__fields">...</div>
 *     </section>
 */
.rb-c-review-request {
  background: none;
  border-radius: var(--rb-c-review-request-border-radius);
  box-shadow: 0px 2px 4px rgba(0, 0, 0, 0.1);
  /**
   * The details pane of the review request.
   *
   * This contains fields and information on the review request, positioned
   * along the side of the main review request fields.
   *
   * Structure:
   *     <div class="rb-c-review-request__details">
   *      <div class="rb-c-review-request-fieldset">...</div>
   *      ...
   *     </div>
   */
  /**
   * Information on a diff in the diff viewer.
   *
   * Structure:
   *     <div class="rb-c-review-request__diff">
   *      ...
   *     </div>
   */
  /**
   * Extra fields for a review request.
   *
   * Structure:
   *     <div class="rb-c-review-request__extra">
   *      ...
   *     </div>
   */
  /**
   * Fields on a review request.
   *
   * This is grouped into the following sections:
   *
   * * Summary
   * * Warning banner
   * * Details fields
   * * Main fields
   * * Extra fields (optional)
   * * Diff information (optional)
   *
   * Structure:
   *     <div class="rb-c-review-request__fields">
   *      <div class="rb-c-review-request__summary">...</div>
   *      <div class="rb-c-review-request__warning">...</div>
   *      <div class="rb-c-review-request__details">...</div>
   *      <div class="rb-c-review-request__main">...</div>
   *      <div class="rb-c-review-request__extra">...</div>
   *      <div class="rb-c-review-request__diff">...</div>
   *     </div>
   */
  /**
   * The header for a review request box.
   *
   * This contains the actions and tabs for the review request.
   *
   * Structure:
   *     <header class="rb-c-review-request__header">
   *      <menu class="rb-c-review-request-tabs">...</menu>
   *      <div class="rb-c-actions">...</div>
   *     </header>
   */
  /**
   * The main fields for a review request.
   *
   * This contains the Description and Testing Done by default.
   *
   * Structure:
   *     <div class="rb-c-review-request__main">
   *      ...
   *     </div>
   */
  /**
   * The summary information for a review request.
   *
   * Structure:
   *     <div class="rb-c-review-request__summary">
   *      ...
   *     </div>
   */
  /**
   * A warning banner for a review request.
   *
   * This will show information when there are validation errors with fields.
   *
   * Structure:
   *     <div class="rb-c-review-request__warning">
   *      ...
   *     </div>
   */
}
.rb-c-review-request__details {
  box-sizing: border-box;
  grid-area: details;
  padding: 1em;
}
.rb-c-review-request__diff {
  grid-area: diff;
  padding: 1em;
}
.rb-c-review-request__extra {
  grid-area: extra;
  padding: 1em;
}
.rb-c-review-request__fields {
  background: var(--rb-c-review-request-bg);
  border: var(--rb-c-review-request-border);
  border-top: 0;
  border-radius: 0 0 var(--rb-c-review-request-border-radius) var(--rb-c-review-request-border-radius);
  clear: both;
  padding: 0.5rem;
  display: grid;
  grid-template-areas: "summary summary" "warning warning" "main    details" "extra   extra" "diff    diff";
  grid-template-columns: 1fr 32em;
  gap: 0 1em;
}
.rb-c-review-request__header {
  border-bottom: var(--rb-c-review-request-border);
  display: flex;
  gap: var(--ink-u-spacing-xxl);
}
@media only screen and (max-width: 800px) {
  .rb-c-review-request__header {
    text-align: center;
  }
}
@media only screen and (max-width: 350px) {
  .rb-c-review-request__header {
    gap: var(--ink-u-spacing-s);
  }
}
.rb-c-review-request__main {
  display: flex;
  flex-direction: column;
  grid-area: main;
  padding: 1em;
  /*
     * Allow this column to resize in favor of the details pane. This overrides
     * a grid cell's default value of 'auto'.
     */
  min-width: 0;
}
.rb-c-review-request__main > .rb-c-review-request-fieldset {
  flex-grow: 1;
}
.rb-c-review-request__main .rb-c-review-request-field:last-child {
  display: flex;
  flex-direction: column;
  flex-grow: 1;
}
.rb-c-review-request__main .rb-c-review-request-field:last-child .editable,
.rb-c-review-request__main .rb-c-review-request-field:last-child .rb-c-inline-editor {
  flex-grow: 1;
}
.rb-c-review-request__summary {
  grid-area: summary;
  padding: 0 1em 1em 1em;
}
.rb-c-review-request__summary p {
  margin: 1em 0 0 0;
}
.rb-c-review-request__summary #field_summary {
  font-size: inherit;
  margin: 0;
  padding: 0;
}
.rb-c-review-request__summary #field_summary a {
  color: black;
  text-decoration: none;
}
.rb-c-review-request__summary .rb-c-review-request-field {
  font-size: 13px;
}
@media screen and (max-width: 720px), screen and (max-device-width: 720px) and (orientation: landscape) {
  .rb-c-review-request__summary .rb-c-review-request-fieldset.-has-inline-fields .rb-c-review-request-field {
    /*
           * There's no longer a baseline to work with, so center this
           * instead.
           */
    align-items: center;
  }
  .rb-c-review-request__summary .rb-c-review-request-fieldset.-has-inline-fields .rb-c-review-request-field__label {
    /* Hide the "Summary:" label on mobile. */
    display: none;
  }
}
.rb-c-review-request__warning {
  background-color: var(--ink-p-accent-error-bg);
  border: 1px var(--ink-p-accent-error-border-color) solid;
  color: var(--ink-p-accent-error-fg);
  display: none;
  font-weight: bold;
  grid-area: warning;
  padding: 5px;
  text-align: center;
}
@media screen and (max-width: 720px), screen and (max-device-width: 720px) and (orientation: landscape) {
  .rb-c-review-request__fields {
    /* Simplify layout, creating a vertical list of block elements. */
    display: block;
  }
}
.required-flag {
  color: var(--rb-p-required-flag-color);
  font-size: var(--ink-u-font-xs);
  font-weight: bold;
  padding: 0 2px;
}
.banner pre.field,
.rb-c-unified-banner pre.field,
.rb-c-review-request-field pre.field,
.rb-c-review-request-changed-fields__value .changedesc-text {
  background-color: var(--ink-p-input-bg);
  border: var(--ink-g-border-input);
  color: var(--ink-p-input-fg);
  margin: var(--rb-c-textarea-margin);
  padding: var(--rb-c-textarea-spacing);
  white-space: pre-wrap;
  word-wrap: break-word;
}
.banner pre.field .codehilite,
.rb-c-unified-banner pre.field .codehilite,
.rb-c-review-request-field pre.field .codehilite,
.rb-c-review-request-changed-fields__value .changedesc-text .codehilite {
  --codehilite-margin-horiz: calc(var(--rb-u-code-block-border-size) + 10px - var(--ink-u-border-thin));
  --codehilite-margin-vert: 3px;
  margin: calc(-1 * var(--codehilite-margin-vert)) calc(-1 * var(--codehilite-margin-horiz));
  padding: var(--codehilite-margin-vert) var(--codehilite-margin-horiz);
}
.banner pre.field .codehilite:before,
.rb-c-unified-banner pre.field .codehilite:before,
.rb-c-review-request-field pre.field .codehilite:before,
.rb-c-review-request-changed-fields__value .changedesc-text .codehilite:before {
  border-left: 0;
  border-right: 0;
  border-radius: 0;
  left: 0;
  right: 0;
}
.editable,
.rb-c-inline-editor-edit-icon {
  line-height: 14px;
}
#field_commit_list {
  display: block;
  position: relative;
}
@media screen and (max-width: 720px), screen and (max-device-width: 720px) and (orientation: landscape) {
  #field_commit_list {
    margin-right: 0;
  }
}
/*
 * Legacy fields for defining sections and labels.
 *
 * Deprecated:
 *     6.0
 */
.review-request-section {
  padding: 1em;
  position: relative;
}
.review-request-section-label {
  color: var(--rb-p-review-request-field-label-color);
  font-size: 12px;
  font-weight: bold;
}
.review-request-main-fieldset {
  display: block;
  position: relative;
}
@media screen and (max-width: 720px), screen and (max-device-width: 720px) and (orientation: landscape) {
  .review-request-main-fieldset {
    margin-right: 0;
  }
}
/****************************************************************************
 * Review request actions
 ****************************************************************************/
/**
 * Review request actions.
 *
 * Actions are grouped into two sections, which are left- and right-aligned.
 * The left-aligned group includes the star and archive actions, and is always
 * visible. The right-aligned group contains all of the editing actions, and
 * will be hidden behind a disclosure when on mobile devices.
 *
 * Structure:
 *     <div class="rb-c-actions" role="presentation">
 *      <menu class="rb-c-actions__content -is-left" role="menu">...</menu>
 *      <menu class="rb-c-actions__content -is-right" role="menu">
 *       <li class="rb-c-actions__action rb-o-mobile-menu-label"
 *           role="presentation">
 *        <a href="#" aria-controls="mobile-actions-menu-content"
 *           aria-expanded="false" aria-haspopup="true">
 *         <span class="fa fa-bars fa-lg" aria-hidden="true"></span>
 *        </a>
 *       </li>
 *       <div id="mobile-actions-menu-content" class="rb-o-mobile-menu">
 *        ...
 *       </div>
 *      </menu>
 *     </div>
 */
.rb-c-review-request .rb-c-actions {
  background: var(--rb-c-review-request-actions-bg);
  border: var(--rb-c-review-request-actions-border);
  border-radius: var(--rb-c-review-request-border-radius) var(--rb-c-review-request-border-radius) 0 0;
  border-bottom-width: 0;
  box-sizing: border-box;
  color: var(--rb-c-review-request-actions-text-color);
  display: flex;
  flex-grow: 1;
  justify-content: space-between;
  min-height: 27px;
  overflow: hidden;
  /**
   * A group of review request actions.
   *
   * Modifiers:
   *     -is-left:
   *         The menu should be floated to the left.
   *
   *     -is-right:
   *         The menu should be floated to the right.
   */
  /**
   * A review request action.
   *
   * Modifiers:
   *     -is-icon:
   *         The action only uses an icon without any additional text.
   *
   * Structure:
   *     <li class="rb-c-actions__action" role="presentation">
   *      <a href="#" role="menuitem">...</a>
   *     </li>
   */
}
.rb-c-review-request .rb-c-actions .ink-c-menu {
  --ink-c-menu-bg: var(--rb-c-review-request-actions-bg);
  --ink-c-menu-border: var(--rb-c-review-request-actions-border);
}
.review-ui-box:not(.has-review-ui-box-content) .rb-c-review-request .rb-c-actions {
  border-radius: var(--rb-c-review-request-border-radius);
}
.rb-c-review-request .rb-c-actions__content {
  /*
     * NOTE: It's important we use a standard block here and not a flexbox
     *       of any kind. We depend on the mobile menu being able to
     *       absolutely-position itself relative to its initial layout
     *       coordinates, and it can't do that in a flexbox. It'll end up
     *       overlapping the whole action bar.
     */
  box-sizing: border-box;
  list-style: none;
  margin: 0;
  padding: 0;
  white-space: nowrap;
}
.rb-c-review-request .rb-c-actions__action {
  /*
     * NOTE: It's important we use a standard inline-block here and not a
     *       flexbox of any kind. We depend on any inner menu components being
     *       able to absolutely-position themselves relative to their initial
     *       layout coordinates, and they can't do that in a flexbox. They'll
     *       end up overlapping the menu controller.
     */
  display: inline-block;
}
.rb-c-review-request .rb-c-actions__action:active,
.rb-c-review-request .rb-c-actions__action:hover {
  background: var(--rb-c-review-request-actions-hover-bg);
}
.rb-c-review-request .rb-c-actions__action a {
  color: inherit;
  cursor: pointer;
  display: flex;
  align-items: center;
  gap: 0.2em;
  margin: 0;
  line-height: 16px;
  text-decoration: none;
  padding: 5px 10px;
}
.rb-c-review-request .rb-c-actions__action.-is-icon > span > a {
  line-height: 0;
  padding: 5px 5px;
}
.rb-c-review-request .rb-c-actions__action.rb-o-mobile-menu-label {
  display: none;
}
@media screen and (max-width: 720px), screen and (max-device-width: 720px) and (orientation: landscape) {
  #review-request .rb-c-actions__action.rb-o-mobile-menu-label {
    display: inline-block;
  }
  #review-request .rb-c-actions__action a,
  #review-request .rb-c-actions__action.-is-icon a {
    /* Give some extra room for tapping. */
    padding: 10px;
  }
  #review-request .rb-c-actions .rb-o-mobile-menu {
    background: #FFFFFF;
    border: 1px #C0C0C0 solid;
    box-shadow: 1px 1px 4px rgba(0, 0, 0, 0.05);
    display: none;
    list-style: none;
    opacity: 0;
    margin: 0;
    padding: 0;
    position: absolute;
    transition: opacity 0.2s linear;
    visibility: hidden;
    z-index: 110;
    /**
   * A menu item.
   *
   * This may contain any content needed in the menu item, but will usually
   * consist of text.
   *
   * The element type may be anything, and will depend on the parent
   * ``.rb-c-menu``. It will most commonly be a ``<li>``, ``<a>``, ``<div>``,
   * or ``<button>``.
   *
   * If displaying a button-based menu, this must have ``.rb-c-button`` mixed
   * in.
   *
   * Consumers are responsible for marking a menu item as focused in response
   * to keyboard navigation or mouse movements, in order to convey the active
   * item.
   *
   * DOM Attributes:
   *     role (required):
   *         This must be set to "menuitem".
   *
   *     tabindex (required):
   *         This must be set to -1, allowing the menu to be focused
   *         programmatically but not through tabbing. Consumers should provide
   *         keep
   *
   * Structure:
   *     <li class="rb-c-menu__item" role="menuitem" tabindex="-1">...</li>
   *
   *     <a class="rb-c-menu__item" role="menuitem" tabindex="-1">...</a>
   *
   *     <button class="rb-c-menu__item rb-c-button" role="menuitem"
   *             type="button" tabindex="-1">
   *      ...
   *     </button>
   */
    /**
   * A menu separator.
   */
    background: var(--rb-c-review-request-actions-bg);
    border: var(--rb-c-review-request-actions-border);
    box-sizing: border-box;
    left: 0;
    width: 100%;
  }
  #review-request .rb-c-actions .rb-o-mobile-menu.-is-open {
    display: block;
    opacity: 1;
    visibility: visible;
  }
  #review-request .rb-c-actions .rb-o-mobile-menu.js-no-animation {
    transition: none;
  }
  #review-request .rb-c-actions .rb-o-mobile-menu__item {
    cursor: pointer;
    display: block;
    list-display: none;
    margin: 0;
  }
  #review-request .rb-c-actions .rb-o-mobile-menu__item.rb-c-button:focus {
    background: #DAEBFF;
    outline: 0;
  }
  #review-request .rb-c-actions .rb-o-mobile-menu__item:not(.rb-c-button) {
    /*
       * We want to apply padding to standard list items, but button list
       * items should retain button padding.
       */
    padding: 0.8em 1em;
  }
  #review-request .rb-c-actions .rb-o-mobile-menu__item:not(.rb-c-button):focus,
  #review-request .rb-c-actions .rb-o-mobile-menu__item:not(.rb-c-button):hover {
    background: #DAEBFF;
    outline: 0;
  }
  #review-request .rb-c-actions .rb-o-mobile-menu__separator {
    border-bottom: 1px #C0C0C0 solid;
  }
  #review-request .rb-c-actions .rb-o-mobile-menu.-is-visible {
    display: block;
    opacity: 1;
    visibility: visible;
  }
  #review-request .rb-c-actions .rb-o-mobile-menu .rb-c-actions__action {
    display: block;
    text-align: left;
    /* This is for submenus. Just display them inline. */
  }
  #review-request .rb-c-actions .rb-o-mobile-menu .rb-c-actions__action .rb-c-menu {
    border: 0;
    border-radius: 0;
    box-shadow: none;
    opacity: 1;
    padding-left: 1em;
    position: inherit;
    visibility: visible;
  }
}
/****************************************************************************
 * Review request tabs
 ****************************************************************************/
/**
 * Review request tabs.
 *
 * Structure:
 *     <menu class="rb-c-review-request-tabs" role="menu">
 *      ...
 *     </menu>
 */
.rb-c-review-request-tabs {
  background-color: var(--rb-c-review-request-actions-bg);
  border: var(--rb-c-review-request-actions-border);
  border-radius: var(--rb-c-review-request-border-radius) var(--rb-c-review-request-border-radius) 0 0;
  border-bottom-width: 0;
  display: flex;
  list-style: none;
  margin: 0 0 -1px 1.5rem;
  overflow: hidden;
  padding: 0;
  /* TODO: dedupe with .review-request-action */
  /**
   * A review request tab.
   *
   * Modifiers:
   *     -is-active:
   *         Designates the active tab element.
   *
   * Structure:
   *     <li class="rb-c-review-request-tabs__tab -is-active"
   *         role="presentation">
   *      <a href="..." role="menuitem" aria-current="page">...</a>
   *     </li>
   *     <li class="rb-c-review-request-tabs__tab" role="presentation">
   *      <a href="..." role="menuitem">...</a>
   *     </li>
   */
}
.rb-c-review-request-tabs__tab {
  border-bottom: var(--rb-c-review-request-actions-border);
  border-left: var(--rb-c-review-request-actions-border);
  min-width: 4rem;
  text-align: center;
}
.rb-c-review-request-tabs__tab:first-child {
  border-left: 0;
}
.rb-c-review-request-tabs__tab.-is-active {
  background: var(--rb-c-review-request-actions-active-bg);
  border-bottom-color: transparent;
  border-width: 0 1px 1px 1px;
}
.rb-c-review-request-tabs__tab:not(.-is-active):active a,
.rb-c-review-request-tabs__tab:not(.-is-active):hover a {
  background: var(--rb-c-review-request-actions-hover-bg);
}
.rb-c-review-request-tabs__tab a {
  color: inherit;
  cursor: pointer;
  display: block;
  margin: 0;
  line-height: 16px;
  text-decoration: none;
  padding: 5px 10px;
}
@media screen and (max-width: 720px), screen and (max-device-width: 720px) and (orientation: landscape) {
  .rb-c-review-request-tabs__tab a {
    /* Give some extra room for tapping. */
    padding: 10px 10px;
  }
}
/****************************************************************************
 * Banners
 ****************************************************************************/
#discard-banner,
#submitted-banner {
  background: var(--if-dark, var(--ink-p-grey-200)) var(--if-light, #E0E0E0);
  border: 1px var(--if-dark, var(--ink-p-grey-300)) var(--if-light, #808080) solid;
}
#draft-banner,
#discard-banner,
#submitted-banner {
  border-top: 0;
  border-left: 0;
  border-right: 0;
  box-shadow: 0px 2px 4px rgba(0, 0, 0, 0.1);
  margin-top: -1.5em;
  margin-left: -1.5em;
  margin-right: -1.5em;
  margin-bottom: 1.5em;
  padding: 1.5em;
}
@media screen and (max-width: 720px), screen and (max-device-width: 720px) and (orientation: landscape) {
  #draft-banner .banner-actions,
  #discard-banner .banner-actions,
  #submitted-banner .banner-actions {
    margin-bottom: 2em;
  }
}
#draft-banner p label,
#discard-banner p label,
#submitted-banner p label {
  display: block;
  line-height: 16px;
  vertical-align: top;
  padding-top: 1em;
}
#draft-banner > p,
#discard-banner > p,
#submitted-banner > p {
  margin: 1em 0 0 0;
}
#draft-banner .interdiff-link {
  margin-top: 1em;
}
/**
 * A notice at the top of a file diff.
 *
 * This should be used any time there's informative content to display above
 * (or in place of) a diff. By default, it shows an informative notice telling
 * the user something they should know about the file, with an info icon and
 * explanatory text on an eye-catching background. Modifiers can be used to
 * adjust the icon or color scheme as appropriate for the type of notice.
 *
 * Version Added:
 *     7.0
 *
 * Modifiers:
 *     -is-deleted-file-notice:
 *         This notice pertains to a deleted file.
 *
 *         This will affect the color scheme of the notice to match that of a
 *         deleted file.
 *
 *     -is-new-file-notice:
 *         This notice pertains to a new file.
 *
 *         This will affect the color scheme of the notice to match that of a
 *         new file.
 *
 *     -is-warning:
 *         The notice is a warning.
 *
 *         This will make use of a warning icon.
 *
 * Structure:
 *     <tbody class="rb-c-diff-file-notice
 *                   [  -is-deleted-file-notice
 *                    | -is-new-file-notice
 *                    | -is-warning]">
 *      <tr>
 *       <td colspan="...">
 *        <div class="rb-c-diff-file-notice__body">...</div>
 *       </td>
 *      </tr>
 *     </tbody>
 */
.sidebyside tbody.rb-c-diff-file-notice {
  --_rb-c-diff-file-notice-icon: var(--ink-c-alert-info-icon);
  background: var(--if-dark, var(--ink-p-header-bg)) var(--if-light, var(--ink-c-alert-warning-bg));
  color: var(--if-dark, var(--ink-p-header-fg)) var(--if-light, var(--ink-c-alert-warning-fg));
  /*
   * Override the default colors for some notice types to reflect the
   * added/deleted status of the file.
   */
  /**
   * The main body of the notice.
   *
   * This inserts an icon and wraps an inner message, ensuring they align.
   *
   * Structure:
   *     <div class="rb-c-diff-file-notice__body">
   *      <div class="rb-c-diff-file-notice__message">...</div>
   *     </div>
   */
  /**
   * Any actions to perform on the notice.
   *
   * DOM Structure:
   *     <div class="rb-c-diff-file-notice__actions">
   *      ...
   *     </div>
   */
  /**
   * The first heading in a message.
   *
   * Not all notices need a heading, as their appearance is bold. They should be
   * used primarily when there's further content to display below it.
   *
   * Structure:
   *     <h3 class="rb-c-diff-file-notice__heading">text...</h3>
   */
  /**
   * A sub-heading in a message.
   *
   * This can be used to separate out content within a message.
   *
   * Structure:
   *     <h4 class="rb-c-diff-file-notice__subheading">text...</h4>
   */
  /**
   * The message within a notice.
   *
   * This contains the headings, text content, and actions shown within the message.
   *
   * Structure:
   *     <div class="rb-c-diff-file-notice__message">
   *      [<div class="rb-c-diff-file-notice__heading">...</div>]
   *      (
   *         <h4 class="rb-c-diff-file-notice__subheading">...</h4>
   *         <div>...</div>
   *       | <p>...</p>
   *       | ...
   *      ) [0+]
   *      [<div class="rb-c-diff-file-notice__actions">...</div>]
   *     </div>
   */
}
.sidebyside tbody.rb-c-diff-file-notice.-is-deleted-file-notice {
  background: var(--rb-theme-diff-delete-bg);
  color: var(--rb-theme-diff-delete-fg);
}
.sidebyside tbody.rb-c-diff-file-notice.-is-new-file-notice {
  background: var(--rb-theme-diff-insert-bg);
  color: var(--rb-theme-diff-insert-fg);
}
.sidebyside tbody.rb-c-diff-file-notice.-is-warning {
  --_rb-c-diff-file-notice-icon: var(--ink-c-alert-warning-icon);
}
.sidebyside tbody.rb-c-diff-file-notice > tr > td {
  padding: 0;
}
.sidebyside tbody.rb-c-diff-file-notice a {
  color: var(--ink-p-link-fg);
}
.sidebyside tbody.rb-c-diff-file-notice .rb-c-diff-file-notice__body {
  display: grid;
  grid-template: "icon message" / min-content auto;
  gap: var(--ink-u-spacing-sm);
  padding: var(--ink-u-spacing-m);
}
.sidebyside tbody.rb-c-diff-file-notice .rb-c-diff-file-notice__body::before {
  display: block;
  grid-area: icon;
  text-align: center;
  background-color: currentColor;
  background-repeat: no-repeat;
  content: "";
  display: inline-block;
  mask-size: 100% 100%;
  mask-image: var(--_rb-c-diff-file-notice-icon);
  width: var(--ink-u-icon-ml);
  height: var(--ink-u-icon-ml);
}
.sidebyside tbody.rb-c-diff-file-notice .rb-c-diff-file-notice__actions {
  margin-top: var(--ink-u-spacing-l);
}
.sidebyside tbody.rb-c-diff-file-notice .rb-c-diff-file-notice__heading {
  font-size: inherit;
  font-weight: bold;
  margin-top: 0;
  padding-top: 0;
}
.sidebyside tbody.rb-c-diff-file-notice .rb-c-diff-file-notice__subheading {
  font-size: inherit;
  font-weight: bold;
  margin-top: var(--ink-u-spacing-l);
  padding-top: 0;
}
.sidebyside tbody.rb-c-diff-file-notice .rb-c-diff-file-notice__message {
  grid-area: message;
  padding-top: var(--ink-u-spacing-xs);
}
/**
 * A review request field for tabular data and filtering.
 */
/**
 * A field for tabular data, with optional filter widgets and tabs.
 *
 * This wraps a table of data, offering consistent styling for headers and
 * cells. It also optionally supports filtering tabs through the
 * ``.rb-c-tabs`` elements, and additional custom filtering controls through
 * ``.rb-c-review-request-field-tabular__filters``.
 *
 * Structure:
 *     <div class="rb-c-review-request-field-tabular">
 *      <header class="rb-c-review-request-field-tabular__header">
 *       <div class="rb-c-review-request-field-tabular__filters">
 *        <div class="rb-c-review-request-field-tabular__filter">
 *         ...
 *        </div>
 *        ...
 *       </div>
 *       <ul class="rb-c-tabs">
 *        ...
 *       </ul>
 *      </header>
 *      <table class="rb-c-review-request-field-tabular__data">
 *       <thead>
 *        <tr>
 *         <th class="-is-sortable">...</th>
 *         ...
 *        </tr>
 *       </thead>
 *       <tbody>
 *        ...
 *       </tbody>
 *      </table>
 *     </div>
 */
.rb-c-review-request-field-tabular {
  /*
   * TODO: this margin shouldn't be dependent on textarea rules, but should be
   * moved into a generic review request field rule.
   */
  margin: var(--rb-c-textarea-margin);
  width: 100%;
  /**
   * A container for any filters to show above the table.
   *
   * By default, filters will be positioned to the top-right of the table,
   * in the same area as any defined tabs. Consumers may need to offer further
   * styling to customize this.
   */
  /**
   * The header area, containing the filters and tabs for the table.
   */
  /**
   * The table data.
   *
   * This is a standard table, which can contain any data.
   *
   * Each table header (a ``<th>`` nested within a ``<thead>``) can have a
   * ``-is-sortable`` modifier class indicating that the header is clickable.
   */
}
.rb-c-review-request-field-tabular__filters {
  position: absolute;
  bottom: 0;
  list-style: none;
  right: 1em;
  margin-bottom: 1em;
}
@media screen and (max-width: 720px), screen and (max-device-width: 720px) and (orientation: landscape) {
  .rb-c-review-request-field-tabular__filters {
    position: initial;
    text-align: right;
  }
}
.rb-c-review-request-field-tabular__filter {
  display: inline-block;
}
.rb-c-review-request-field-tabular__header {
  margin: 1.5em 0 -1px 0;
  padding-bottom: 0;
  position: relative;
}
.rb-c-review-request-field-tabular__data {
  border: var(--ink-c-data-table-border);
  border-radius: 6px;
  border-spacing: 0;
  overflow: hidden;
  width: 100%;
}
.rb-c-review-request-field-tabular__data tbody {
  background: var(--ink-c-data-table-body-bg);
  color: var(--ink-c-data-table-body-fg);
}
.rb-c-review-request-field-tabular__data tbody tr {
  background: var(--ink-c-data-table-row-bg);
}
.rb-c-review-request-field-tabular__data tbody tr.-is-hidden {
  display: none;
}
.rb-c-review-request-field-tabular__data tbody td {
  padding: var(--ink-c-data-table-cell-padding);
  vertical-align: top;
}
.rb-c-review-request-field-tabular__data thead th {
  color: var(--ink-c-data-table-header-fg);
  cursor: pointer;
  padding: var(--ink-c-data-table-cell-padding);
  text-align: left;
  white-space: nowrap;
}
.rb-c-review-request-field-tabular__data thead th.-is-sortable:hover {
  text-decoration: underline;
}
.rb-c-review-request-field-tabular__data thead tr {
  background: var(--ink-c-data-table-header-bg);
}
.rb-c-review-request-field-tabular .rb-c-tabs {
  margin-left: 2.5em;
}
@media screen and (max-width: 720px), screen and (max-device-width: 720px) and (orientation: landscape) {
  .rb-c-review-request-field-tabular .rb-c-tabs {
    margin-left: 0.5em;
  }
}
/**
 * A list of commits, with expandable messages, metadata, and controls.
 *
 * The commit list is used to show a list of commits, along with useful
 * information for each commit. This is used in the following places:
 *
 * 1. On the main review request page.
 *
 * 2. On a Change Description, showing the differences between commit
 *    histories.
 *
 * 3. On the diff viewer, with controls for selecting ranges.
 *
 * 4. On interdiffs in the diff viewer, showing the differences between
 *    commit histories.
 *
 * This handles all these use cases, allowing for optional history diff
 * indicators and selection controls.
 *
 * This is meant to be mixed in with ``.rb-c-review-request-field-tabular``.
 *
 * Structure:
 *     <div class="rb-c-review-request-field-tabular rb-c-commit-list">
 *      <table class="rb-c-review-request-field-tabular__data">
 *       <thead>
 *        <tr>
 *         ...leading control/diff marker <th> tags here..
 *         <th>Summary</th>
 *         <th>ID</th>
 *         <th>Author</th>
 *        </tr>
 *       </thead>
 *       <tbody>
 *        <tr class="rb-c-commit-list__commit ...>...</tr>
 *        ...
 *       </tbody>
 *      </table>
 *     </div>
 */
.rb-c-commit-list {
  /**
   * The author for a commit.
   *
   * Structure:
   *     <td class="rb-c-commit-list__author">...</td>
   */
  /**
   * A commit in the list.
   *
   * This row will contain a commit message, ID, author, and possibly
   * information on a diff history operation or selection controls.
   *
   * If showing a diff history, a modifier may be applied to indicate the
   * diff operation or state of the commit.
   *
   * Modifiers:
   *     -is-added:
   *         This commit was added to the history.
   *
   *     -is-modified:
   *         This commit was modified in the history.
   *
   *     -is-removed:
   *         This commit was removed from the history.
   *
   * Structure:
   *     <tr class="rb-c-commit-list__commit">
   *      <td class="rb-c-commit-list__message">...</td>
   *      <td class="rb-c-commit-list__id">...</td>
   *      <td class="rb-c-commit-list__author">...</td>
   *     </tr>
   *
   *     \3c !-- If showing diff information -->
   *     <tr class="rb-c-commit-list__commit [modifiers]">
   *      <td class="rb-c-commit-list__op">...</td>
   *      <td class="rb-c-commit-list__message">...</td>
   *      <td class="rb-c-commit-list__id">...</td>
   *      <td class="rb-c-commit-list__author">...</td>
   *     </tr>
   *
   *     \3c !-- If showing selection controls -->
   *     <tr class="rb-c-commit-list__commit">
   *      <td class="rb-c-commit-list__select-base">...</td>
   *      <td class="rb-c-commit-list__select-tip">...</td>
   *      <td class="rb-c-commit-list__message">...</td>
   *      <td class="rb-c-commit-list__id">...</td>
   *      <td class="rb-c-commit-list__author">...</td>
   *     </tr>
   */
  /**
   * The ID of a commit.
   *
   * This will truncate up to about 8-10 digits. It should have a ``title``
   * attribute for seeing the full ID.
   *
   * DOM Attributes:
   *     title (string):
   *         The full commit ID.
   */
  /**
   * The summary and message for a commit.
   *
   * This will show the summary of the commit. If a commit message body is
   * available, it should be wrapped in a ``<details>``.
   *
   * Structure:
   *     \3c !-- If only a summary is available: -->
   *     <td class="rb-c-commit-list__message">
   *      <div class="rb-c-commit-list__message-summary">...</div>
   *     </td>
   *
   *     \3c !-- If a summary and body is available: -->
   *     <td class="rb-c-commit-list__message">
   *      <details>
   *       <summary class="rb-c-commit-list__message-summary">...</summary>
   *       <div class="rb-c-commit-list__message-body">...</div>
   *      </details>
   *     </td>
   */
  /**
   * The body of a commit message.
   *
   * This includes pre-wrapped text. There should be no extra spacing between
   * the tags and text.
   *
   * Structure:
   *     <div class="rb-c-commit-list__message-body">text...</div>
   */
  /**
   * The summary of a commit message.
   *
   * Structure:
   *     \3c !-- If in a <details>: -->
   *     <summary class="rb-c-commit-list__message-summary">text...</summary>
   *
   *     \3c !-- If not in a <details>: -->
   *     <div class="rb-c-commit-list__message-summary">text...</div>
   */
  /**
   * A commit history diff operation indicator for the commit.
   *
   * This will be updated to show an appropriate icon, depending on the
   * modifiers on the parent ``.rb-c-commit-list__commit``.
   *
   * DOM Attributes:
   *     aria-label (string):
   *         A label describing the operation or state.
   *
   * Structure:
   *     <td class="rb-c-commit-list__op">...</td>
   */
}
.rb-c-commit-list__author {
  max-width: 20em;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
}
.rb-c-commit-list__commit.-is-added .rb-c-commit-list__op {
  background: var(--rb-p-diff-insert-op-bg);
  color: var(--rb-p-diff-insert-op-fg);
}
.rb-c-commit-list__commit.-is-added .rb-c-commit-list__op::before {
  display: inline-block;
  font: normal normal normal 14px/1 FontAwesome;
  font-size: inherit;
  text-rendering: auto;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
  content: "\f067";
}
.rb-c-commit-list__commit.-is-modified .rb-c-commit-list__op {
  background: var(--rb-p-diff-replace-op-bg);
  color: var(--rb-p-diff-replace-op-fg);
}
.rb-c-commit-list__commit.-is-modified .rb-c-commit-list__op::before {
  content: "~";
  font-weight: bold;
}
.rb-c-commit-list__commit.-is-removed .rb-c-commit-list__op {
  background: var(--rb-p-diff-delete-op-bg);
  color: var(--rb-p-diff-delete-op-fg);
}
.rb-c-commit-list__commit.-is-removed .rb-c-commit-list__op::before {
  display: inline-block;
  font: normal normal normal 14px/1 FontAwesome;
  font-size: inherit;
  text-rendering: auto;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
  content: "\f068";
}
.rb-c-commit-list__id {
  max-width: 10em;
  overflow: hidden;
  text-overflow: ellipsis;
}
.rb-c-commit-list__message {
  font-family: var(--ink-ff-monospace);
  font-size: inherit;
  width: 100%;
}
.rb-c-commit-list__message details,
.rb-c-commit-list__message summary {
  border: 0;
  margin: 0;
  padding: 0;
}
.rb-c-commit-list__message summary {
  cursor: pointer;
}
.rb-c-commit-list__message-body {
  margin-top: 2em;
  white-space: pre-wrap;
}
@media screen and (max-width: 720px), screen and (max-device-width: 720px) and (orientation: landscape) {
  .rb-c-commit-list__column-author,
  .rb-c-commit-list__column-id,
  .rb-c-commit-list__author,
  .rb-c-commit-list__id {
    display: none;
  }
  .rb-c-commit-list__author {
    text-align: right;
    flex-grow: 1;
    max-width: none;
  }
}
/**
 * Styles for the field state label.
 */
/**
 * A label indicating the state of a field.
 *
 * Modifiers:
 *     -is-deleted:
 *         The label will have a deleted color theme.
 *
 *     -is-draft:
 *         The label will have a draft color theme.
 *
 *     -is-inline:
 *         The label will be displayed inline.
 *
 * Structure:
 *     <div class="rb-c-field-state-label [modifiers]">
 *      ...
 *     </div>
 */
.rb-c-field-state-label {
  border-radius: var(--ink-u-border-radius-s);
  line-height: 1.4;
  padding: 0 0.4em;
  width: fit-content;
}
.rb-c-field-state-label.-is-deleted {
  background: #FFE0E5;
  border: var(--ink-u-border-thin) solid #EA3939;
  color: #EA3939;
}
.rb-c-field-state-label.-is-draft {
  background: var(--rb-p-flag-draft-bg);
  border: var(--ink-u-border-thin) solid var(--rb-p-flag-draft-border-color);
  color: var(--rb-p-flag-draft-fg);
}
.rb-c-field-state-label.-is-inline {
  display: inline;
}
/**
 * The Issue Summary Table, used to filter and view issues on a review request.
 *
 * This is meant to be used along with ``.rb-c-review-request-tabular``, and
 * builds upon that to provide styling for the different issue states.
 */
.rb-c-issue-summary-table {
  /**
   * An issue counter on a tab.
   */
  /**
   * A special row indicating that no issues exist matching the filter.
   */
  /**
   * The main table containing the list of issues.
   */
}
.rb-c-issue-summary-table__counter {
  vertical-align: middle;
}
.rb-c-issue-summary-table .rb-c-review-request-field-tabular__data tr.rb-c-issue-summary-table__no-issues {
  --_rb-c-issue-summary-table-row-text-color-dark: var(--ink-p-fg);
}
.rb-c-issue-summary-table .rb-c-review-request-field-tabular__data tr.rb-c-issue-summary-table__no-issues td,
.rb-c-issue-summary-table .rb-c-review-request-field-tabular__data tr.rb-c-issue-summary-table__no-issues td:hover {
  background: var(--if-dark, none) var(--if-light, white);
}
.rb-c-issue-summary-table .rb-c-review-request-field-tabular__data tr {
  --_rb-c-issue-summary-table-row-bg-light: var(--rb-p-issue-bg);
  --_rb-c-issue-summary-table-row-hover-bg-light: #f2e48a;
  --_rb-c-issue-summary-table-row-text-color-dark: var(--rb-p-issue-open-accent-text-color);
  /* Add borders separating groups of different types of statuses. */
}
.rb-c-issue-summary-table .rb-c-review-request-field-tabular__data tr[data-issue-id] {
  cursor: pointer;
}
.rb-c-issue-summary-table .rb-c-review-request-field-tabular__data tr:not(.-is-hidden).-is-open + .rb-c-issue-summary-table__issue:not(.-is-open) td,
.rb-c-issue-summary-table .rb-c-review-request-field-tabular__data tr:not(.-is-hidden).-is-dropped + .rb-c-issue-summary-table__issue:not(.-is-dropped) td,
.rb-c-issue-summary-table .rb-c-review-request-field-tabular__data tr:not(.-is-hidden).-is-resolved + .rb-c-issue-summary-table__issue:not(.-is-resolved) td {
  border-top-color: #C0C0C0;
}
@media screen and (max-width: 720px), screen and (max-device-width: 720px) and (orientation: landscape) {
  .rb-c-issue-summary-table .rb-c-review-request-field-tabular__data tr:not(.-is-hidden).-is-open + .rb-c-issue-summary-table__issue:not(.-is-open) td,
  .rb-c-issue-summary-table .rb-c-review-request-field-tabular__data tr:not(.-is-hidden).-is-dropped + .rb-c-issue-summary-table__issue:not(.-is-dropped) td,
  .rb-c-issue-summary-table .rb-c-review-request-field-tabular__data tr:not(.-is-hidden).-is-resolved + .rb-c-issue-summary-table__issue:not(.-is-resolved) td {
    border-top-color: transparent;
  }
}
.rb-c-issue-summary-table .rb-c-review-request-field-tabular__data tr.-is-dropped {
  --_rb-c-issue-summary-table-row-bg-light: #ECECEC;
  --_rb-c-issue-summary-table-row-hover-bg-light: #dfdfdf;
  --_rb-c-issue-summary-table-row-text-color-dark: var(--rb-p-issue-dropped-accent-text-color);
}
.rb-c-issue-summary-table .rb-c-review-request-field-tabular__data tr.-is-resolved {
  --_rb-c-issue-summary-table-row-bg-light: #FAFAFA;
  --_rb-c-issue-summary-table-row-hover-bg-light: #ededed;
  --_rb-c-issue-summary-table-row-text-color-dark: var(--rb-p-issue-resolved-accent-text-color);
}
.rb-c-issue-summary-table .rb-c-review-request-field-tabular__data tr.-is-verifying-dropped,
.rb-c-issue-summary-table .rb-c-review-request-field-tabular__data tr.-is-verifying-resolved {
  --_rb-c-issue-summary-table-row-bg-light: #fff8ca;
  --_rb-c-issue-summary-table-row-hover-bg-light: #f5e9a1;
}
.rb-c-issue-summary-table .rb-c-review-request-field-tabular__data tr td {
  background: var(--if-dark, none) var(--if-light, var(--_rb-c-issue-summary-table-row-bg-light));
  color: var(--if-dark, var(--_rb-c-issue-summary-table-row-text-color-dark)) var(--if-light, var(--ink-p-fg-on-light));
  /*
         * All text should be vertically centered in relation to the issue
         * status icon, meaning we need to give them all the line height of
         * the icon. From there, we'll make further adjustments below.
         */
  line-height: 16px;
  /* Description column */
}
.rb-c-issue-summary-table .rb-c-review-request-field-tabular__data tr td:hover {
  background: var(--if-dark, var(--ink-p-container-hover-bg)) var(--if-light, var(--_rb-c-issue-summary-table-row-hover-bg-light));
}
.rb-c-issue-summary-table .rb-c-review-request-field-tabular__data tr td:nth-child(1) {
  width: 100%;
}
.rb-c-issue-summary-table .rb-c-review-request-field-tabular__data tr td a {
  text-decoration: none;
}
.rb-c-issue-summary-table .rb-c-review-request-field-tabular__data tr td p {
  margin: 0;
  padding: 0;
  overflow: hidden;
}
.rb-c-issue-summary-table .rb-c-review-request-field-tabular__data tr td time {
  white-space: nowrap;
}
.rb-c-issue-summary-table .rb-c-review-request-field-tabular__data tr td .rb-c-user {
  white-space: nowrap;
}
.rb-c-issue-summary-table .rb-c-review-request-field-tabular__data tr td .rb-c-user__avatar {
  /*
             * We're aiming to keep all text aligned across the row.
             * rb-c-user takes care of baseline alignment for the avatar and
             * text, and the rest of the row is also using baseline, so this
             * should work.
             *
             * We also can't let the avatar take up too much vertical space on
             * the row. So, we're offsetting the vertical margins a bit to
             * reduce the space required (offsetting into the cell's padding
             * a bit instead). This creates a mostly-vertically-centered look
             * while keeping the text aligned.
             */
  margin-top: -4px;
  margin-bottom: -4px;
}
.rb-c-issue-summary-table .rb-c-review-request-field-tabular__data tr td .rb-icon {
  float: left;
  margin-right: 6px;
}
@media screen and (max-width: 720px), screen and (max-device-width: 720px) and (orientation: landscape) {
  .rb-c-issue-summary-table .rb-c-review-request-field-tabular__data tbody {
    display: block;
  }
  .rb-c-issue-summary-table .rb-c-review-request-field-tabular__data thead {
    /*
         * Ensure this doesn't get set on mobile when transitioning between
         * tabs. JavaScript will try to manage the display.
         */
    display: none !important;
  }
  .rb-c-issue-summary-table .rb-c-review-request-field-tabular__data tr {
    display: flex;
  }
  .rb-c-issue-summary-table .rb-c-review-request-field-tabular__data td:nth-child(1) {
    flex-grow: 1;
    max-width: 75%;
  }
  .rb-c-issue-summary-table .rb-c-review-request-field-tabular__data td:nth-child(1) .rb-icon {
    margin-left: 0;
  }
  .rb-c-issue-summary-table .rb-c-review-request-field-tabular__data td:nth-child(2) {
    max-width: 25%;
    overflow: hidden;
    text-overflow: ellipsis;
  }
  .rb-c-issue-summary-table .rb-c-review-request-field-tabular__data td:nth-child(3) {
    display: none;
  }
}
/**
 * A component for viewing and changing the issue status of a comment.
 *
 * This displays a horizontal bar that shows an icon and text reflecting the
 * current issue status for a published comment, with action buttons for
 * fixing, dropping, reopening, or verifying an issue, along with a link for
 * viewing the Issue Summary Table.
 *
 * Version Added:
 *     7.0
 *
 * DOM Attributes:
 *     aria-labelledby (string):
 *         The ID of the inner label.
 *
 *     data-can-verify (boolean):
 *         Whether the user requires verification.
 *
 *     data-comment-id (number):
 *         The ID of the comment.
 *
 *     data-comment-type (string):
 *         The type of the comment.
 *
 *         Valid values include those present in
 *         :js:class:`RB.IssueCommentManagerCommentType`.
 *
 *     data-interactive (boolean):
 *         Whether the issue can be interacted with by the user.
 *
 *         If ``true``, action buttons will be available.
 *
 *     data-issue-status (string):
 *         The current issue status.
 *
 * Modifiers:
 *     -is-compact:
 *         Place the issue bar in a compact mode.
 *
 *         This will remove the issues link, and use a more vertical
 *         orientation useful in short widths.
 *
 * Structure:
 *     <div class="rb-c-issue-bar
 *                 [-is-compact]"
 *          aria-labelledby="<<string>>"
 *          data-can-verify="<<boolean>>"
 *          data-comment-id="<<number>>"
 *          data-comment-type="<<string>>"
 *          data-interactive="<<boolean>>"
 *          data-issue-status="open | dropped | resolved |
 *                             verifying-dropped | verifying-resolved">
 *      <span class="rb-c-issue-bar__icon" ...></span>
 *      <label class="rb-c-issue-bar__message" ...></label>
 *      <span class="rb-c-issue-bar__actions" ...></span>
 *      <a class="rb-c-issue-bar__all-issues-link" ...></a>
 *     </div>
 */
.rb-c-issue-bar {
  /* Presentation */
  --_rb-c-issue-status-bg-light: transparent;
  --_rb-c-issue-status-border-color-light: transparent;
  --_rb-c-issue-status-border-color-dark: transparent;
  --_rb-c-issue-status-link-color-light: inherit;
  --_rb-c-issue-status-text-color-light: var(--ink-p-fg-on-light);
  --_rb-c-issue-status-text-color-dark: var(--ink-p-fg-on-light);
  /*
   * On dark mode, use a yellow base for the button colors, and keep the
   * background neutral. Our splashes of color will be purely on the icon,
   * text, and buttons.
   */
  --ink-p-accent-primary-bg: var(--if-light, inherit) var(--if-dark, var(--ink-p-grey-500));
  --ink-p-accent-secondary-bg: var(--if-light, inherit) var(--if-dark, white);
  --ink-p-accent-tertiary-bg: var(--if-light, inherit) var(--if-dark, var(--ink-p-grey-500));
  --ink-p-accent-primary-fg: var(--if-light, inherit) var(--if-dark, var(--ink-p-fg-on-light));
  background: var(--if-light, var(--_rb-c-issue-status-bg-light)) var(--if-dark, rgba(255, 255, 255, 0.1));
  border: 1px var(--if-light, var(--_rb-c-issue-status-border-color-light)) var(--if-dark, var(--_rb-c-issue-status-border-color-dark)) solid;
  border-radius: var(--ink-u-border-radius-std);
  color: var(--if-light, var(--_rb-c-issue-status-text-color-light)) var(--if-dark, var(--_rb-c-issue-status-text-color-dark));
  font-weight: bold;
  transition: 0.1s linear all;
  /* Layout */
  display: grid;
  grid-template-areas: "icon message actions link";
  grid-template-columns: min-content auto 1fr auto;
  align-items: center;
  gap: var(--ink-u-spacing-std);
  padding: var(--ink-u-spacing-s) var(--ink-u-spacing-m);
  /**
   * The actions available to the user.
   *
   * The following buttons are available based on the current issue status:
   *
   * ``open``:
   *     Resolve and Drop.
   *
   * ``dropped``:
   *     Re-open.
   *
   * ``resolved``:
   *     Re-open.
   *
   * ``verifying-dropped``:
   *     Re-open and Verify Dropped.
   *
   * ``verifying-resolved``:
   *     Re-open and Verify Fixed.
   *
   * Structure:
   *     <div class="rb-c-issue-bar__actions">
   *      [
   *       <button class="ink-c-button"
   *               type="button"
   *               data-action="resolve">
   *        Fixed
   *       </button>
   *      ]
   *      [
   *       <button class="ink-c-button"
   *               type="button"
   *               data-action="drop">
   *        Drop
   *       </button>
   *      ]
   *      [
   *       <button class="ink-c-button"
   *               type="button"
   *               data-action="reopen">
   *        Re-open
   *       </button>
   *      ]
   *      [
   *       <button class="ink-c-button"
   *               type="button"
   *               data-action="verify-dropped">
   *        Verify Dropped
   *       </button>
   *      ]
   *      [
   *       <button class="ink-c-button"
   *               type="button"
   *               data-action="verify-resolved">
   *        Verify Fixed
   *       </button>
   *      ]
   *     </div>
   */
  /**
   * A link taking the user to the Issue Summary Table.
   *
   * Structure:
   *     <a class="rb-c-issue-bar__all-issues-link"
   *        href="...">
   *      Show all issues
   *     </a>
   */
  /**
   * The icon representing the issue status.
   *
   * DOM Attributes:
   *     aria-hidden (boolean):
   *         ``true``, always.
   *
   * Structure:
   *     <span class="rb-c-issue-bar__icon"
   *           aria-hidden="true"></span>
   */
  /**
   * The message describing the current issue status.
   *
   * DOM Attributes:
   *     id (string):
   *         A unique ID for the label.
   *
   *         This value must be placed in ``aria-labelledby` in
   *         ``.rb-c-issue-bar``.
   *
   * Structure:
   *     <label class="rb-c-issue-bar__message"
   *            id="<<string>>"
   *      text...
   *     </label>
   */
}
.rb-c-issue-bar.-is-compact {
  grid-template-areas: "icon message" ".    actions";
  grid-template-columns: min-content auto min-content;
  grid-template-rows: 1fr 1fr;
}
.rb-c-issue-bar.-is-compact .rb-c-issue-bar__actions {
  margin-left: 0;
}
.rb-c-issue-bar.-is-compact .rb-c-issue-bar__all-issues-link {
  display: none;
}
.rb-c-issue-bar[data-issue-status="open"] {
  --_rb-c-issue-status-bg-light: var(--rb-p-issue-bg);
  --_rb-c-issue-status-link-color-light: var(--ink-p-fg-weak-on-light);
}
.rb-c-issue-bar[data-issue-status="open"] .rb-c-issue-bar__icon {
  background-position: -26px -5px;
  width: 16px;
  height: 16px;
}
.rb-c-issue-bar[data-issue-status="dropped"] {
  --_rb-c-issue-status-bg-light: #ECECEC;
  --_rb-c-issue-status-border-color-light: #b9b9b9;
  --_rb-c-issue-status-link-color-light: #535353;
  --_rb-c-issue-status-text-color-light: var(--ink-p-fg-on-light);
  --_rb-c-issue-status-text-color-dark: var(--rb-p-issue-dropped-accent-text-color);
}
.rb-c-issue-bar[data-issue-status="dropped"] .rb-c-issue-bar__icon {
  background-position: -5px -5px;
  width: 16px;
  height: 16px;
}
.rb-c-issue-bar[data-issue-status="resolved"] {
  --_rb-c-issue-status-bg-light: #FAFAFA;
  --_rb-c-issue-status-border-color-light: #e1e1e1;
  --_rb-c-issue-status-link-color-light: #616161;
  --_rb-c-issue-status-text-color-dark: var(--rb-p-issue-resolved-accent-text-color);
}
.rb-c-issue-bar[data-issue-status="resolved"] .rb-c-issue-bar__icon {
  background-position: -47px -5px;
  width: 16px;
  height: 16px;
}
.rb-c-issue-bar[data-issue-status="verifying-resolved"],
.rb-c-issue-bar[data-issue-status="verifying-dropped"] {
  --_rb-c-issue-status-bg-light: #fff8ca;
}
.rb-c-issue-bar[data-issue-status="verifying-resolved"] .rb-c-issue-bar__icon,
.rb-c-issue-bar[data-issue-status="verifying-dropped"] .rb-c-issue-bar__icon {
  background-position: -117px -107px;
  width: 16px;
  height: 16px;
}
.rb-c-issue-bar[data-issue-status="open"],
.rb-c-issue-bar[data-issue-status="verifying-resolved"],
.rb-c-issue-bar[data-issue-status="verifying-dropped"] {
  --_rb-c-issue-status-border-color-light: var(--rb-p-issue-border-color);
  --_rb-c-issue-status-border-color-dark: var(--rb-p-issue-border-color);
  --_rb-c-issue-status-text-color-light: var(--ink-p-fg-on-light);
  --_rb-c-issue-status-text-color-dark: var(--rb-p-issue-open-accent-text-color);
  --ink-p-accent-primary-bg: var(--if-light, inherit) var(--if-dark, var(--ink-p-yellow-300));
  --ink-p-accent-secondary-bg: var(--if-light, inherit) var(--if-dark, var(--ink-p-yellow-800));
  --ink-p-accent-tertiary-bg: var(--if-light, inherit) var(--if-dark, var(--ink-p-yellow-500));
  --ink-p-accent-primary-fg: var(--if-light, inherit) var(--if-dark, var(--ink-p-fg-on-light));
}
.rb-c-issue-bar__actions {
  grid-area: actions;
  display: flex;
  flex-grow: 1;
  gap: var(--ink-u-spacing-s);
  margin-left: var(--ink-u-spacing-std);
}
.rb-c-issue-bar__all-issues-link {
  grid-area: link;
  font-size: var(--ink-u-font-sm);
  font-weight: normal;
  white-space: nowrap;
}
.rb-c-issue-bar__all-issues-link,
.rb-c-issue-bar__all-issues-link:link,
.rb-c-issue-bar__all-issues-link:visited,
.rb-c-issue-bar__all-issues-link:hover {
  color: var(--if-light, var(--_rb-c-issue-status-link-color-light)) var(--if-dark, inherit);
}
.rb-c-issue-bar__all-issues-link:hover {
  text-decoration: underline;
}
.rb-c-issue-bar__icon {
  grid-area: icon;
  background-repeat: no-repeat;
  display: inline-block;
  overflow: hidden;
  text-indent: -99999px;
  vertical-align: middle;
  /* Set up the default image and size. */
  background-image: url('../../images/icons.png');
  background-size: 155px 150px;
  /*
   * If there are 2 or more ratio levels, loop through and create media
   * selectors for each.
   */
  /*
   * If SVG is enabled, create a media selector for it based on the max
   * ratio.
   */
}
@media (min-resolution: 1.5dppx) {
  .rb-c-issue-bar__icon {
    background-image: url(../../images/icons@2x.png);
    background-size: 155px 150px;
  }
}
@media (min-resolution: 192dpi) {
  .rb-c-issue-bar__icon {
    background-image: url(../../images/icons@2x.png);
    background-size: 155px 150px;
  }
}
@media (min-resolution: 288dpi) {
  .rb-c-issue-bar__icon {
    background-image: url(../../images/icons.svg);
    background-size: 155px 150px;
  }
}
.rb-c-issue-bar__message {
  grid-area: message;
}
@media screen and (max-width: 720px), screen and (max-device-width: 720px) and (orientation: landscape) {
  .rb-c-issue-bar {
    grid-template-areas: "icon message message" ".    actions link";
    grid-template-columns: min-content auto min-content;
    grid-template-rows: 1fr 1fr;
  }
  .rb-c-issue-bar__actions {
    margin-left: 0;
  }
}
.rb-c-review-request-field,
:root {
  --rb-p-review-request-field-label-color: var(--if-light, #575022) var(--if-dark, var(--ink-p-fg-weak));
}
/**
 * A container for a field on a review request.
 *
 * This is a wrapper for an editable field on a review request. It provides
 * structure for a label and a container for a field's HTML or displayed value.
 *
 * Version Added:
 *     6.0
 *
 * DOM Attributes:
 *     aria-labelledby (string):
 *         The ID of the field label.
 *
 *     role (string):
 *         This should always be "group".
 *
 * Structure:
 *     <div class="rb-c-review-request-field"
 *          aria-labelledby="..."
 *          role="group">
 *      <label class="rb-c-review-request-field__label" ...>...</label>
 *      <div class="rb-c-review-request-field__value">...</div>
 *     </div>
 */
.rb-c-review-request-field {
  display: flex;
  flex-direction: column;
  vertical-align: text-top;
  /**
   * The label for a field.
   *
   * DOM Attributes:
   *     for (string):
   *         The ID of the inner field or value.
   *
   *     id (string):
   *         The ID of the field, for the parent element's ``aria-labelledby``.
   *
   * Structure:
   *     <label class="rb-c-review-request-field__label"
   *            for="..."
   *            id="...">
   *      text...
   *     </label>
   */
  /**
   * The inner field or value to show and manage.
   *
   * This may contain a field type like an ``<input>`` or ``<textarea>``, or
   * a rendered value, or a ``rb-c-inline-editor``, or any combination of those.
   *
   * Structure:
   *     <div class="rb-c-review-request-field__value">
   *      field...
   *     </div>
   */
}
.rb-c-review-request-field__label {
  color: var(--rb-p-review-request-field-label-color);
  font-size: inherit;
  font-weight: bold;
}
.rb-c-review-request-field__value {
  display: flex;
  flex-direction: column;
  flex-grow: 1;
  position: relative;
  /*
     * Special styling to ensure Enable Markdown checkboxes are centered.
     * In the future, we'll want to style this in a more general way.
     */
}
.rb-c-review-request-field__value .enable-markdown {
  display: flex;
  align-items: center;
}
/**
 * A set of fields on a review request.
 *
 * This groups together one or more fields on a review request in a top-down
 * form (default) or a tabular form (used for the review request details area).
 *
 * If the fieldset is marked to have inline fields, then each field label will
 * have a ``:`` appended.
 *
 * This will generally contain ``.rb-c-review-request-field`` children, but
 * are not required to.
 *
 * Note that this should not use the ``<fieldset>`` tag, as that tag has hidden
 * structure that can interfere with tabular form.
 *
 * Version Added:
 *     6.0
 *
 * Modifiers:
 *     -has-inline-fields:
 *         The fieldset contains inline fields. All field labels will have a
 *         ``:`` appended.
 *
 *     -is-tabular:
 *         The field layout should appear in a tabular form, with each field
 *         in a row of label and value columns.
 *
 * DOM Attributes:
 *     aria-label (string):
 *         The label of the fieldset, if the fieldset does not contain a
 *         ``.rb-c-review-request-fieldset__label`` part.
 *
 *         If a label part does exist, use ``aria-labelledby``.
 *
 *     aria-labelledby (string):
 *         The ID of the ``.rb-c-review-request-fieldset__label`` part for the
 *         fieldset, if one is used.
 *
 *         If a label part does not exist, use ``aria-label``.
 *
 *     role (string):
 *         This should always be "group".
 *
 * Structure:
 *     <div class="rb-c-review-request-fieldset"
 *          aria-labelledby="..."
 *          role="group">
 *      <h3 class="rb-c-review-request-fieldset__label">...</h3>
 *      ...
 *     </div>
 */
.rb-c-review-request-fieldset {
  display: flex;
  flex-direction: column;
  border: 0;
  margin: 0;
  padding: 0;
  gap: 2em;
  /**
   * The optional label for the fieldset.
   *
   * Structure:
   *     <h3 class="rb-c-review-request-fieldset__label" id="...">
   *      text...
   *     </h3>
   */
}
.rb-c-review-request-fieldset.-has-inline-fields .rb-c-review-request-field {
  display: flex;
  align-items: baseline;
  flex-direction: row;
  gap: 0.5em;
  /*
       * We want to leave enough room for the inline editor to grow. We opt
       * for both of these methods in order to handle both tabular and
       * non-tabular forms. The line-height is needed for any table-based
       * layout and the min-height is needed for any flexboxes.
       */
  line-height: 2.5em;
  min-height: 2.5em;
}
.rb-c-review-request-fieldset.-has-inline-fields .rb-c-review-request-field__label:after {
  content: ":";
}
.rb-c-review-request-fieldset.-has-inline-fields .rb-c-review-request-field__value {
  display: inline-flex;
  flex-direction: row;
  flex-grow: 1;
}
.rb-c-review-request-fieldset.-has-inline-fields .rb-c-review-request-field__value .rb-c-inline-editor {
  flex-grow: 1;
}
.rb-c-review-request-fieldset.-has-inline-fields .editable:empty + .rb-c-inline-editor-edit-icon {
  /* Avoid an unwanted margin when alongside an empty value. */
  margin-left: 0;
}
.rb-c-review-request-fieldset.-is-tabular {
  display: table-row-group;
}
.rb-c-review-request-fieldset.-is-tabular .rb-c-review-request-field {
  display: table-row;
}
.rb-c-review-request-fieldset.-is-tabular .rb-c-review-request-field__label {
  display: table-cell;
  font-size: inherit;
  text-align: right;
  white-space: nowrap;
}
.rb-c-review-request-fieldset.-is-tabular .rb-c-review-request-field__value {
  display: table-cell;
  width: 100%;
}
.rb-c-review-request-fieldset.-is-tabular .rb-c-review-request-field__label,
.rb-c-review-request-fieldset.-is-tabular .rb-c-review-request-field__value {
  padding: 0 0 0.5em 1em;
}
.rb-c-review-request-fieldset__label {
  color: var(--rb-p-review-request-field-label-color);
  font-size: inherit;
  font-weight: bold;
  margin: 0;
  padding: 2em 0 1em 0;
  text-align: left;
}
/**
 * A list of fields that were changed in a review request update.
 *
 * This groups together all the field changes that were made in a single
 * review request update, along with the change description itself.
 *
 * This will hold a label and a value for each field. The value is free-form,
 * and many types (legacy and modern) are supported. For simple field changes,
 * this can be paired with ``.rb-c-review-request-changed-field``.
 *
 * Version Added:
 *     7.0
 *
 * DOM Attributes:
 *     aria-label (string):
 *         A label describing the list.
 *
 *         This can be ``Changed fields``.
 *
 * Structure:
 *     <dl class="rb-c-review-request-changed-fields"
 *         aria-label="<<string>>">
 *      <div class="rb-c-review-request-changed-fields__field">...</div> [1+]
 *     </dl>
 */
.rb-c-review-request-changed-fields {
  box-sizing: border-box;
  display: grid;
  grid-template-columns: min-content auto;
  gap: var(--ink-u-spacing-l) var(--ink-u-spacing-std);
  margin: 0;
  padding: 12px;
  width: 100%;
  /**
   * A changed field in the list.
   *
   * By default, the field's label and value will be shown side-by-side in a grid
   * form, if space permits. A field can instead be made wide using the ``-is-wide``
   * modifier, forcing the label to appear above the value, giving the value the
   * full available width.
   *
   * Modifiers:
   *     -is-wide:
   *         Whether to show the field in a wide view.
   *
   * Structure:
   *     <div class="rb-c-review-request-changed-fields__field">
   *      <dt class="rb-c-review-request-changed-fields__label" ...>
   *       ...
   *      </dt>
   *      <dd class="rb-c-review-request-changed-fields__value" ...>
   *       ...
   *      </dd>
   *     </div>
   */
  /*
   * The label for a changed field.
   *
   * DOM Attributes:
   *     id (string):
   *         A unique ID assumed to this label.
   *
   * Structure:
   *     <dt class="rb-c-review-request-changed-fields__label"
   *         id="<<string>>">
   *      text...
   *     </dt>
   */
  /*
   * The value for a changed field.
   *
   * DOM Attributes:
   *     aria-labelledby (string):
   *         The ID of the matching ``.rb-c-review-request-changed-fields__label``.
   *
   * Structure:
   *     <dd class="rb-c-review-request-changed-fields__value"
   *         aria-labelledby="<<string>>">
   *      html...
   *     </dd>
   */
}
.rb-c-review-request-changed-fields__field {
  align-items: baseline;
  grid-column: 1 / 3;
  /*
     * We have a variety of types of content in the values, and not all can be
     * aligned with a baseline. Tweak these for the built-in types of content.
     *
     * Note that :has support is available in all browsers that support subgrid.
     */
}
.rb-c-review-request-changed-fields__field.-is-wide {
  display: flex;
  flex-direction: column;
  gap: var(--ink-u-spacing-std);
}
.rb-c-review-request-changed-fields__field.-is-wide .rb-c-review-request-changed-fields__label,
.rb-c-review-request-changed-fields__field.-is-wide .rb-c-review-request-changed-fields__value {
  text-align: left;
  width: 100%;
}
.rb-c-review-request-changed-fields__field:not(.-is-wide) {
  display: grid;
  /*
       * For browsers that don't support subgrids, we'll have to set a minimum field
       * width in order to ideally keep things aligned, while allowing the label to
       * grow if needed. This can create a staggered look for older browsers.
       */
  /*
       * For browsers that support subgrids, we can easily keep all the fields
       * aligned.
       */
}
.rb-c-review-request-changed-fields__field:not(.-is-wide) .rb-c-review-request-changed-fields__label {
  text-align: right;
}
@supports not (grid-template-columns: subgrid) {
  .rb-c-review-request-changed-fields__field:not(.-is-wide) {
    gap: var(--ink-u-spacing-std);
    grid-template-columns: minmax(10em, min-content) auto;
  }
}
@supports (grid-template-columns: subgrid) {
  .rb-c-review-request-changed-fields__field:not(.-is-wide) {
    grid-template-columns: subgrid;
  }
}
@media screen and (max-width: 720px), screen and (max-device-width: 720px) and (orientation: landscape) {
  .rb-c-review-request-changed-fields__field:not(.-is-wide) {
    display: flex;
    flex-direction: column;
    gap: var(--ink-u-spacing-std);
  }
  .rb-c-review-request-changed-fields__field:not(.-is-wide) .rb-c-review-request-changed-fields__label,
  .rb-c-review-request-changed-fields__field:not(.-is-wide) .rb-c-review-request-changed-fields__value {
    text-align: left;
    width: 100%;
  }
}
.rb-c-review-request-changed-fields__field:has(.rb-c-review-request-field-tabular) {
  align-self: start;
}
.rb-c-review-request-changed-fields__field:has(.rb-c-review-request-field-tabular) .rb-c-review-request-changed-fields__label {
  align-self: start;
  padding-top: calc(var(--ink-u-border-thin) + var(--ink-c-data-table-cell-padding-vert));
}
.rb-c-review-request-changed-fields__field:has(.diffed-text-area, .file-container) {
  align-items: start;
}
.rb-c-review-request-changed-fields__field:has(.diffed-text-area, .file-container) .rb-c-review-request-changed-fields__label {
  padding-top: var(--ink-u-spacing-xs);
}
.rb-c-review-request-changed-fields__label {
  color: var(--rb-p-review-request-field-label-color);
  font-weight: bold;
  margin: 0;
  padding: 0;
  white-space: nowrap;
}
.rb-c-review-request-changed-fields__value {
  margin: 0;
  padding: 0;
}
/*
 * Special styles for different types of rendered values.
 *
 * In time, each of these should be given their own components with proper
 * styling. For now, we need to specially handle each of these.
 */
.rb-c-review-request-changed-fields__value {
  /* Used in the textarea field diffs and the Change Summary section. */
  /* Reset the content within the value to display properly. */
  /*
   * File attachment/screenshot change lists.
   *
   * These differ from the other field change lists in that they have
   * mini-section labels underneath for each file.
   */
  /* The "Change Summary" section. */
  /* The diff for text areas. */
  /* Styling for the "Diff" field updates. */
  /* Styles for the file listing for the "Diff" field. */
}
.rb-c-review-request-changed-fields__value > pre {
  background-color: var(--ink-p-input-bg);
  border: var(--ink-g-border-input);
  color: var(--ink-p-input-fg);
  padding: var(--rb-c-textarea-spacing);
  font-size: inherit;
  white-space: pre-wrap;
}
.rb-c-review-request-changed-fields__value .file-container,
.rb-c-review-request-changed-fields__value .file-container .file,
.rb-c-review-request-changed-fields__value .rb-c-review-request-field-tabular {
  margin: 0;
}
.rb-c-review-request-changed-fields__value .rb-c-file-attachments {
  display: flex;
  flex-wrap: wrap;
  gap: var(--ink-u-spacing-std);
}
.rb-c-review-request-changed-fields__value .rb-c-file-attachments .file-container {
  float: none;
}
.rb-c-review-request-changed-fields__value .rb-c-file-attachments .file-container .file {
  margin: 0;
}
.rb-c-review-request-changed-fields__value .caption-changed {
  margin: 0 0 0 var(--ink-u-spacing-std);
  padding: 0;
}
.rb-c-review-request-changed-fields__value .caption-changed a {
  /* Treat the link like a field. */
  font-weight: bold;
}
.rb-c-review-request-changed-fields__value .caption-changed td,
.rb-c-review-request-changed-fields__value .caption-changed th {
  vertical-align: top;
}
.rb-c-review-request-changed-fields__value .caption-changed td {
  padding-left: 1em;
}
.rb-c-review-request-changed-fields__value .caption-changed th {
  text-align: right;
}
.rb-c-review-request-changed-fields__value .changedesc-text {
  margin: 0;
  padding: var(--rb-c-textarea-spacing);
  overflow: hidden;
  width: 100%;
}
.rb-c-review-request-changed-fields__value .changedesc-text .codehilite:before {
  border-left: 0;
  border-right: 0;
  border-radius: 0;
  left: 0;
  right: 0;
}
.rb-c-review-request-changed-fields__value .changedesc-text:last-child {
  margin-bottom: 0;
}
.rb-c-review-request-changed-fields__value .diffed-text-area {
  background: var(--ink-p-input-bg);
  border: var(--ink-g-border-input);
  border-collapse: collapse;
  color: var(--ink-p-input-fg);
  padding: 0;
  width: 100%;
  /* Add borders between different change types. */
  /* The '-' or '+' marker. */
}
.rb-c-review-request-changed-fields__value .diffed-text-area a {
  text-decoration: underline;
}
.rb-c-review-request-changed-fields__value .diffed-text-area p {
  padding-top: 2px;
  padding-bottom: 2px;
}
.rb-c-review-request-changed-fields__value .diffed-text-area pre {
  background: none;
  border: 0;
  margin: 0;
  padding: 0;
  white-space: pre-wrap;
}
.rb-c-review-request-changed-fields__value .diffed-text-area td {
  font-family: var(--rb-c-textarea-font-family);
  padding: 0 4px;
  vertical-align: top;
  white-space: pre-wrap;
}
.rb-c-review-request-changed-fields__value .diffed-text-area td .codehilite {
  border-radius: 0;
  border-left: 0;
  border-right: 0;
  /* Make this flush with the sides of the row. */
  margin: 0 -4px;
  /* Don't obscure the text or shift it to any side. Make it flush. */
}
.rb-c-review-request-changed-fields__value .diffed-text-area td .codehilite:before {
  border-left: 0;
  border-right: 0;
  border-radius: 0;
  left: 0;
  right: 0;
}
.rb-c-review-request-changed-fields__value .diffed-text-area td .codehilite::before {
  background: none;
  border: 0;
}
.rb-c-review-request-changed-fields__value .diffed-text-area td .codehilite.codehilite-multiline-start {
  border-top: var(--rb-g-code-block-border);
}
.rb-c-review-request-changed-fields__value .diffed-text-area td .codehilite.codehilite-multiline-end {
  border-bottom: var(--rb-g-code-block-border);
}
.rb-c-review-request-changed-fields__value .diffed-text-area td .codehilite pre:empty {
  /* Give this a reasonable height so it's not just blank. */
  height: 1rem;
}
.rb-c-review-request-changed-fields__value .diffed-text-area .delete {
  /* The '-' or '+' marker. */
}
.rb-c-review-request-changed-fields__value .diffed-text-area .delete .line {
  background: var(--rb-theme-diff-delete-bg);
  color: var(--rb-theme-diff-delete-fg);
}
.rb-c-review-request-changed-fields__value .diffed-text-area .delete .marker {
  background: var(--rb-theme-diff-delete-linenum-bg);
  color: var(--rb-theme-diff-delete-linenum-fg);
}
.rb-c-review-request-changed-fields__value .diffed-text-area .insert {
  /* The '-' or '+' marker. */
}
.rb-c-review-request-changed-fields__value .diffed-text-area .insert .line {
  background: var(--rb-theme-diff-insert-bg);
  color: var(--rb-theme-diff-insert-fg);
}
.rb-c-review-request-changed-fields__value .diffed-text-area .insert .marker {
  background: var(--rb-theme-diff-insert-linenum-bg);
  color: var(--rb-theme-diff-insert-linenum-fg);
}
.rb-c-review-request-changed-fields__value .diffed-text-area :not(.insert) + .insert,
.rb-c-review-request-changed-fields__value .diffed-text-area :not(.equal) + .equal,
.rb-c-review-request-changed-fields__value .diffed-text-area :not(.delete) + .delete {
  border-top: var(--rb-g-diff-chunk-border);
}
.rb-c-review-request-changed-fields__value .diffed-text-area .line {
  width: 100%;
  word-break: break-all;
  /*
       * Make sure any images in the Markdown-rendered text are kept
       * small, but with the correct aspect ratio.
       */
}
.rb-c-review-request-changed-fields__value .diffed-text-area .line img {
  width: auto;
  max-height: 100px;
}
.rb-c-review-request-changed-fields__value .diffed-text-area .marker {
  background: var(--rb-theme-diff-equals-linenum-bg);
  color: var(--rb-theme-diff-equals-linenum-fg);
  font-family: var(--rb-c-textarea-font-family);
  font-size: var(--rb-c-textarea-font-size);
  font-weight: bold;
  text-align: center;
}
.rb-c-review-request-changed-fields__value .diffed-text-area .replace-new {
  /* The '-' or '+' marker. */
}
.rb-c-review-request-changed-fields__value .diffed-text-area .replace-new .line {
  background: var(--rb-theme-diff-insert-bg);
  color: var(--rb-theme-diff-insert-fg);
}
.rb-c-review-request-changed-fields__value .diffed-text-area .replace-new .line .hl {
  background: var(--rb-g-diff-highlight-text-bg);
  color: var(--rb-g-diff-highlight-text-fg);
}
.rb-c-review-request-changed-fields__value .diffed-text-area .replace-new .marker {
  background: var(--rb-theme-diff-insert-linenum-bg);
  color: var(--rb-theme-diff-insert-linenum-fg);
}
.rb-c-review-request-changed-fields__value .diffed-text-area .replace-old {
  /* The '-' or '+' marker. */
}
.rb-c-review-request-changed-fields__value .diffed-text-area .replace-old .line {
  background: var(--rb-theme-diff-delete-bg);
  color: var(--rb-theme-diff-delete-fg);
}
.rb-c-review-request-changed-fields__value .diffed-text-area .replace-old .line .hl {
  background: var(--rb-g-diff-highlight-text-bg);
  color: var(--rb-g-diff-highlight-text-fg);
}
.rb-c-review-request-changed-fields__value .diffed-text-area .replace-old .marker {
  background: var(--rb-theme-diff-delete-linenum-bg);
  color: var(--rb-theme-diff-delete-linenum-fg);
}
.rb-c-review-request-changed-fields__value .diff-changes {
  margin-top: 0;
  padding-top: 0;
}
.rb-c-review-request-changed-fields__value .diff-changes .line-counts {
  margin-left: 0.5em;
}
.rb-c-review-request-changed-fields__value .diff-changes .line-counts .delete-count {
  color: var(--rb-p-diff-delete-text-fg);
}
.rb-c-review-request-changed-fields__value .diff-changes .line-counts .insert-count {
  color: var(--rb-p-diff-insert-text-fg);
}
.rb-c-review-request-changed-fields__value .diff-index {
  margin-bottom: 0;
  overflow-wrap: anywhere;
}
.rb-c-review-request-changed-fields__value .diff-index .diff-file-icon {
  min-width: 20px;
  min-height: 20px;
}
.rb-c-review-request-changed-fields__value .diff-index .diff-file-info {
  /* Compensate for the lack of diff-chunks-cell column. */
  width: 100%;
}
/**
 * A diffed change to a simple field value on a review request.
 *
 * This shows a change in a value, such as a summary or list of bugs. It's
 * presented as a deleted line and an added line, using ``-`` and ``+`` markers.
 *
 * The old and new values are optional, but at least one must be provided.
 *
 * This is not suitable for all types of changes. It should not be used for
 * multi-line text fields or anything requiring a graphical representation.
 *
 * Version Added:
 *     7.0
 *
 * Structure:
 *     <div class="rb-c-review-request-changed-value">
 *      [<div class="rb-c-review-request-changed-value__old">...</div>]
 *      [<div class="rb-c-review-request-changed-value__new">...</div>]
 *     </div>
 */
.rb-c-review-request-changed-value {
  /*
   * NOTE: Keep font, colors, and icons in sync with rb-c-commit-list until we
   *       come up with common definitions.
   */
  background: var(--ink-p-input-bg);
  border: var(--ink-g-border-input);
  border-radius: var(--ink-u-border-radius-s);
  display: flex;
  flex-direction: column;
  overflow: hidden;
  width: fit-content;
  /**
   * A marker showing whether a value is old or new.
   *
   * DOM Attributes:
   *     aria-label (string):
   *         A label describing whether this is an old or new value.
   *
   * Structure:
   *     <div class="rb-c-review-request-changed-value__marker"
   *          aria-label="<<string>>"></div>
   */
  /**
   * The new value for a field.
   *
   * DOM Attributes:
   *     aria-label (string):
   *         A label stating this is a new value.
   *
   * Structure:
   *     <div class="rb-c-review-request-changed-value__new">
   *      <div class="rb-c-review-request-changed-value__marker" ...></div>
   *      <div class="rb-c-review-request-changed-value__value" ...>...</div>
   *     </div>
   */
  /**
   * The old value for a field.
   *
   * DOM Attributes:
   *     aria-label (string):
   *         A label stating this is an old value.
   *
   * Structure:
   *     <div class="rb-c-review-request-changed-value__new">
   *      <div class="rb-c-review-request-changed-value__marker" ...></div>
   *      <div class="rb-c-review-request-changed-value__value" ...>...</div>
   *     </div>
   */
  /**
   * The displayed old or new value.
   *
   * Structure:
   *     <div class="rb-c-review-request-changed-value__value">html...</div>
   */
}
.rb-c-review-request-changed-value__marker {
  align-self: stretch;
}
.rb-c-review-request-changed-value__marker::before {
  display: inline-block;
  font: normal normal normal 14px/1 FontAwesome;
  font-size: inherit;
  text-rendering: auto;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
}
.rb-c-review-request-changed-value__new .rb-c-review-request-changed-value__marker {
  background: var(--rb-p-diff-insert-op-bg);
  color: var(--rb-p-diff-insert-op-fg);
}
.rb-c-review-request-changed-value__new .rb-c-review-request-changed-value__marker::before {
  content: "\f067";
}
.rb-c-review-request-changed-value__old .rb-c-review-request-changed-value__marker {
  background: var(--rb-p-diff-delete-op-bg);
  color: var(--rb-p-diff-delete-op-fg);
}
.rb-c-review-request-changed-value__old .rb-c-review-request-changed-value__marker::before {
  content: "\f068";
}
.rb-c-review-request-changed-value__value {
  font-family: var(--rb-c-textarea-font-family);
}
.rb-c-review-request-changed-value__value a {
  color: var(--ink-p-link-fg);
  text-decoration: none;
}
.rb-c-review-request-changed-value__value a:first-child {
  margin-left: 0;
}
.rb-c-review-request-changed-value__value a:hover {
  text-decoration: underline;
}
.rb-c-review-request-changed-value__new,
.rb-c-review-request-changed-value__old {
  display: flex;
  align-items: baseline;
}
.rb-c-review-request-changed-value__marker,
.rb-c-review-request-changed-value__value {
  display: table-cell;
  padding: var(--ink-c-data-table-cell-padding);
}
/**
 * A component for rendering the thumbnail context for a comment.
 *
 * This is used for both draft comments (in the Review Dialog) and in
 * published comments (on a review).
 *
 * It manages a consistent header style, along with a content area that
 * contains the rendered thumbnail content. The thumbnail content may be
 * an image, lines of text, or an entire diff.
 *
 * There is a special case when it comes to diffs. For a diff, the header
 * is fully rendered as part of the diff display (as it may contain multiple
 * columns). In this case, this component will style the header within the
 * diff, and should not be given a separate header.
 *
 * Version Added:
 *     7.0
 *
 * DOM Attributes:
 *     aria-label (string):
 *         A label describing this thumbnail.
 *
 *         It should contain an identifier beyond just the filename/revision.
 *         For example, "File attachment thumbnail for my-filename.png".
 *
 * Modifiers:
 *     -expands-on-hover:
 *         Whether a contained diff will expand additional controls on hover.
 *
 *         This requires the ``-has-diff`` modifier.
 *
 *     -has-diff:
 *         Whether this thumbnail contains a diff.
 *
 * Structure:
 *     <div class="rb-c-review-comment-thumbnail
 *                 [-has-diff
 "                  [-expands-on-hover]]">
 *          aria-labelledby="<<string>>">
 *      [<div class="rb-c-review-comment-thumbnail__header">...</div>]
 *      <div class="rb-c-review-comment-thumbnail__content">...</div>
 *     </div>
 */
.rb-c-review-comment-thumbnail {
  /**
   * The content of the thumbnail.
   *
   * This may contain any arbitrary HTML needed to represent the thumbnail.
   *
   * Structure:
   *     <div class="rb-c-review-comment-thumbnail__content">
   *      html...
   *     </div>
   */
  /**
   * The header area for the thumbnail.
   *
   * This must be present for all comment thumbnail types except for diffs.
   *
   * Clicking it should navigate to the reviewed content.
   *
   * DOM Attributes:
   *     href (string):
   *         The URL to the exact content that was commented on.
   *
   * Structure:
   *     <a class="rb-c-review-comment-thumbnail__header"
   *        href="<<string>>">
   *      <span class="rb-c-review-comment-thumbnail__name">...</span>
   *      [<span class="rb-c-review-comment-thumbnail__revision">...</span>]
   *     </a>
   */
  /**
   * The name of the content that was commented on.
   *
   * Structure:
   *     <span class="rb-c-review-comment-thumbnail__name">
   *      text...
   *     </span>
   */
  /**
   * The revision of the content that was commented on.
   *
   * Structure:
   *     <span class="rb-c-review-comment-thumbnail__revision">
   *      text...
   *     </span>
   */
  /*
   * The following provides styling for both the parts of this component and
   * an embedded diff.
   */
  /* Ensure the header's revision uses a consistent font size and style. */
  /*
   * Set the borders around the header.
   */
  /* Ensure a consistent color and text decoration for headers. */
  /* Additional styling for embedded diffs. */
}
.rb-c-review-comment-thumbnail.-has-diff {
  /*
     * Disable the border on the content, since we want the bottom part of the
     * diff to expand.
     */
}
.rb-c-review-comment-thumbnail.-has-diff .sidebyside {
  /*
       * This ensures that diff comments don't spill outside of the review
       * box on mobile.
       */
}
@media only screen and (max-width: 800px) {
  .rb-c-review-comment-thumbnail.-has-diff .sidebyside {
    display: grid;
  }
}
@media only screen and (max-width: 800px) {
  .rb-c-review-comment-thumbnail.-has-diff .sidebyside .filename-row {
    display: grid;
  }
}
.rb-c-review-comment-thumbnail.-has-diff.-expands-on-hover {
  /*
       * Set up some animations for the hover effects.
       *
       * For diffs, when collapsed, the contents of the headers will be
       * transparent, showing just a few pixels of the background to show
       * that there's something there.
       *
       * When expanding, the contents will be fully opaque.
       *
       * Both are done as transitions and their states managed in JavaScript.
       * The result is that the controls will appear to expand outward from the
       * diff (using transforms, without impacting the layout of the rest of the
       * page), with the contents fading in/out.
       */
}
.rb-c-review-comment-thumbnail.-has-diff.-expands-on-hover .sidebyside,
.rb-c-review-comment-thumbnail.-has-diff.-expands-on-hover .sidebyside thead,
.rb-c-review-comment-thumbnail.-has-diff.-expands-on-hover .sidebyside .diff-header,
.rb-c-review-comment-thumbnail.-has-diff.-expands-on-hover .sidebyside .diff-header td > div {
  transition: all 0.3s linear;
}
.rb-c-review-comment-thumbnail.-has-diff .rb-c-review-comment-thumbnail__content {
  border-bottom: 0;
}
.rb-c-review-comment-thumbnail.-has-diff .sidebyside:not(.has-diff-header-above) {
  /*
         * If there's no diff header above, then we won't have a file
         * header that's retracted. In this case, we want to add back the
         * margin that we'd normally have in a comment section.
         */
  margin-top: 4em;
}
.rb-c-review-comment-thumbnail.-has-diff .sidebyside:not(.has-diff-header-below) {
  /*
         * Diff comment sections don't have a bottom border. We leave it
         * up to the diff headers to supply one normally. If there isn't a
         * diff header below the diff, add our own border.
         */
  border-bottom: 1px var(--ink-u-border-thin) var(--ink-p-container-border-color) solid solid;
}
.rb-c-review-comment-thumbnail.-has-diff .sidebyside .diff-header-above {
  transform-origin: bottom;
}
.rb-c-review-comment-thumbnail.-has-diff .sidebyside .diff-header-below {
  transform-origin: top;
}
.rb-c-review-comment-thumbnail.-has-diff .sidebyside .diff-header td > div {
  overflow: hidden;
}
.rb-c-review-comment-thumbnail__content {
  border-bottom: var(--ink-u-border-thin) var(--ink-p-container-border-color) solid;
  overflow-x: auto;
}
.rb-c-review-comment-thumbnail__content > img {
  display: block;
  max-width: 100%;
  height: auto;
}
.rb-c-review-comment-thumbnail__header {
  display: block;
}
.rb-c-review-comment-thumbnail__name {
  font-size: var(--ink-u-font-m);
  font-weight: bold;
  text-align: left;
  text-overflow: ellipsis;
}
.rb-c-review-comment-thumbnail__revision,
.rb-c-review-comment-thumbnail .diffrevision {
  font-size: var(--ink-u-font-sm);
  font-weight: normal;
}
.rb-c-review-comment-thumbnail__header,
.rb-c-review-comment-thumbnail .sidebyside .filename-row th {
  background: var(--rb-g-diff-box-header-bg);
  border-top: var(--ink-u-border-thin) var(--ink-p-container-border-color) solid;
  padding: var(--ink-u-spacing-sm);
  /*
     * For diffs, normally the revision row has this border, but for diff
     * fragments, we want to place it on the filename row.
     */
  border-bottom: var(--ink-u-border-thin) var(--ink-p-container-border-color) solid;
}
.rb-c-review-comment-thumbnail__header:link,
.rb-c-review-comment-thumbnail .sidebyside .filename-row a:link,
.rb-c-review-comment-thumbnail__header:visited,
.rb-c-review-comment-thumbnail .sidebyside .filename-row a:visited {
  color: var(--rb-g-diff-box-header-fg);
  text-decoration: none;
}
.rb-c-review-comment-thumbnail__header:hover .rb-c-review-comment-thumbnail__name,
.rb-c-review-comment-thumbnail .sidebyside .filename-row a:hover {
  text-decoration: underline;
}
.rb-c-review-comment-thumbnail .diff-error tbody {
  border: var(--ink-u-border-thin) var(--ink-p-accent-warning-border-color) solid;
}
.rb-c-review-comment-thumbnail .sidebyside {
  border: 0;
  margin: 0;
}
.rb-c-review-comment-thumbnail .sidebyside th {
  /*
       * The line numbers aren't clickable in the comment fragments in reviews,
       * so show a standard cursor instead of a pointer.
       */
  cursor: initial;
}
.rb-c-review-comment-thumbnail .sidebyside.collapsed .diff-header td > div {
  opacity: 0;
}
.rb-c-review-comment-thumbnail .sidebyside.expanded .diff-header td > div {
  opacity: 1;
}
.rb-c-review-comment-thumbnail .sidebyside .first-comment-line td,
.rb-c-review-comment-thumbnail .sidebyside .first-comment-line th {
  border-top: 1px var(--if-light, black) var(--if-dark, yellow) solid;
}
.rb-c-review-comment-thumbnail .sidebyside .last-comment-line td,
.rb-c-review-comment-thumbnail .sidebyside .last-comment-line th {
  border-bottom: 1px var(--if-light, black) var(--if-dark, yellow) solid;
}
.dnd-overlay {
  background: rgba(0, 0, 0, 0.8);
  border: solid 2px grey;
  box-sizing: border-box;
  color: #dddddd;
  font-size: 150%;
  position: absolute;
  text-align: center;
  vertical-align: middle;
  z-index: 210;
  left: 0;
  top: 0;
  width: 100%;
  height: 100%;
}
.dnd-overlay-highlight {
  background: rgba(26, 26, 26, 0.8);
}
/*# sourceMappingURL=reviews.css.map */